package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See L<http://www.perl.com/perl/misc/Artistic.html>

=cut


__DATA__
M?T5,1@$"`0`````````````"`!0````!$``9$````#0``,]$```````T`"``
M"``H`!X`'0````8````T$```-!```#0```$````!``````4````$`````P``
M`300``$T$``!-`````T````-````!`````$````!`````!`````0``````!C
MH```8Z`````%``$```````$``'``$`%P`!`!<````%WY``!N.`````8``0``
M`````@``<"`0`7`@$`%P(````0@```$(````!@````0````$```!1!```400
M``%$````1````$0````$````!&1TY5```&,X$`!C.!``8S@````4````%```
M``0````$9'3E40``````````````````````````````!@````0O;&EB+VQD
M+G-O+C$`````````!````!`````!1TY5```````````"````!@```!H````$
M````%`````-'3E4`=E]%\5!4LX`FA7/RM^!!)`2]'*\```!A````:```````
M`````````````#T`````````60```#8`````````*P```$`````:````````
M`!\````9````6``````````0````2@```$L````D````70```&4````J````
M.0``````````````#P```%0```!!``````````````!/````5@```"D````W
M`````````&<```!.````.````#$`````````,P````````!3`````````$D`
M``!#``````````````!A````$0```"`````6``````````````!5````'@``
M`"T````A```````````````O`````````"8``````````````$4`````````
M!P```$(````_````.P```"(````^``````````````!>````40```"<````%
M````/`````8````R`````````%\```````````````````!@````4```````
M```H````5P```"4```!$````6@```"P`````````````````````````````
M``0``````````````````````````````&(```````````````(`````````
M``````````````````````````!F````$@```!,`````````````````````
M````8P`````````-```````````````<````6P```&0```!&`````````!4`
M``!'`````````%(````````````````````;````"`````D`````````%```
M`#`````````````````````````````````````8``````````$```!,````
M````````````````-0```#H````=````30``````````````````````````
M````````````````````"@```#0````+````````````````````%P````,`
M```C``````````X````````````````````N````````````````````````
M```````````````````````,````7````$@``````````````!$```!&````
M"`````@$$!P`@@1`)0!``#BH`8:B`B`$0`D$*`M%,J(X"`P$B@```$8```!'
M````2P```%````!1````6````%L```!<````7@```&``````````8@```&0`
M``!E````9@``````````:TKP>Q_?Q6X.[]/J+4?>SGR:?VNVF\4N#N3_(,6.
M07P.\8VX?-1DU1Q8<=D!QD?BP.-+K!W3V_)\DN.Z+#_EPF!LH?IOBP&SUD,)
M:JEARI2!G/F'9LRO9QR+\CCLU45#GN(4#'&RU<F>X\W:[=MB,PN7.@R6FZ17
MFYRI?PH"I^%7$(H*2?O@HP````````````````````````+6```````````2
M```````#6P``````````$@```````@,``````````!(```````-T````````
M```1```````#UP``````````$@```````TP``````````!(```````$'````
M```````2```````"XP``````````$@```````)T``````````!(```````+=
M```````````2````````>0``````````$@```````0(``````````!(`````
M``*-```````````2```````#'```````````$@```````IX``````````!(`
M``````%K```````````2```````#+```````````$@```````R,`````````
M`!(```````$K```````````2````````JP``````````$@```````;4`````
M`````!(```````%2```````````2```````"3```````````$@```````?L`
M`````````!(```````*Z```````````2```````!H@``````````$@``````
M`JL``````````!(```````&N```````````2```````!.0``````````$@``
M`````!$``````````"````````)>```````````2```````#,P``````````
M$@```````$(``````````!(```````+(```````````2```````#8@``````
M````$@```````SH``````````!(```````'T```````````2````````V0``
M````````$@```````(@``````````!(```````%@```````````2```````"
MSP``````````$@```````J4``````````!(```````)S```````````2````
M```"'```````````$@```````K,``````````!(````````T```````````2
M```````"A0``````````$@```````0P``````````!(```````&7````````
M```2````````Y@``````````$@```````U0``````````!(```````+!````
M```````2```````#=0``````````(0```````7D``````````!(````````@
M```````````@```````"8P``````````$@```````+T``````````!(`````
M``%)```````````2```````#0@``````````$@```````%$``````````!(`
M``````)K```````````2```````#=@``````````$0```````OT`````````
M`!(```````((```````````2```````"Z@``````````$@```````BT`````
M`````!(```````)\```````````2```````"]0``````````$@```````P<`
M`````````!(```````&'$`!9P``````2```````#X!``5IP```#0$@``#0``
M`ZX0`%[0`````!(```X```0%$`!'$```"X`2```-```#;Q``%M````)`$@``
M#0```[00`#YD````#!(```T```1E$``^<````DP2```-```$DA``5VP```!0
M$@``#0``!%\0`!:$`````!(```P```2N$`!2D```!`P2```-```#DQ`!S?D`
M````$`#_\0```^P0`$"\````4!(```T```(]$`!?&`````01```/```!P!`!
MS@@````3$0``&@```Y\0`=XX`````!``__$```1=$``]`````$02```-```$
M<A``1;````%@$@``#0``!(00`$3\````@!(```T```02$`%R2``````0```9
M```$11`"3?D`````$```&0```&@0`%R@`````!(```````/Y$`!!#````<`2
M```-```#%1`!S?P````$$0``&@```XP0`<WY`````!``__$```.D$`!8$```
M``02```-```!&!``6_``````$@``````!#40`%@@````M!(```T```08$``9
M$````"02```-```$%!`!<D@`````(```&0```/<0`<X`````!!$``!H```/%
M$`!%?````#02```-```$'Q``/:0```#`$@``#0```,P0`<X$`````1$``!H`
M``10$`!"S````C`2```-`&QI8G!E<FPN<V\N-2XQ-`!?7V=M;VY?<W1A<G1?
M7P!?2G9?4F5G:7-T97)#;&%S<V5S`%!E<FQ?<WES7W1E<FT`4&5R;%]S>7-?
M:6YI=#,`4&5R;%]S879E7V1E<W1R=6-T;W)?>`!097)L7V%T9F]R:U]L;V-K
M`'!E<FQ?8V]N<W1R=6-T`%!E<FQ?8W)O86M?;F]C;VYT97AT`%!E<FQ?879?
M<VAI9G0`4&5R;%]S=E\R<'9?9FQA9W,`4&5R;%]S=E]S971P=FX`4$Q?9&]?
M=6YD=6UP`%!E<FQ?;F5W4U9P=@!097)L7VYE=UA37V9L86=S`%!,7W1H<E]K
M97D`<&5R;%]F<F5E`%!E<FQ?;6=?<V5T`%!E<FQ?871F;W)K7W5N;&]C:P!0
M97)L7W-V7W-E='!V`%!E<FQ?9W9?9F5T8VAP=@!P97)L7W)U;@!097)L7V1O
M=6YW:6YD`%!E<FQ?;F5W6%,`<&5R;%]D97-T<G5C=`!097)L7V%V7V9E=&-H
M`&)O;W1?1'EN84QO861E<@!P97)L7W!A<G-E`%!E<FQ?<V%F97-Y<VUA;&QO
M8P!P97)L7V%L;&]C`%!,7VUE;6]R>5]W<F%P`&QI8F1L+G-O+C(`;&EB;2YS
M;RXV`&QI8G!T:')E860N<V\N,`!O<&5N-C0`;'-E96LV-`!R96%D`'!T:')E
M861?9V5T<W!E8VEF:6,`7U]E<G)N;U]L;V-A=&EO;@!C;&]S90!L:6)C+G-O
M+C8`7TE/7W-T9&EN7W5S960`7U]R96=I<W1E<E]A=&9O<FL`97AI=`!S<')I
M;G1F`'-T<FYC;7``7U]S=')D=7``8VQO<V5D:7(`<W1R;F-P>0!?7W-T86-K
M7V-H:U]F86EL`'5N;&EN:P!M:V1I<@!R96%L;&]C`&UE;6-H<@!G971P:60`
M<W1R=&]K`'-T<FQE;@!M96US970`<W1R<W1R`')M9&ER`&UE;6-P>0!?7VQX
M<W1A=#8T`&]P96YD:7(`7U]X<W1A=#8T`%]?8W1Y<&5?8E]L;V,`<W1D97)R
M`&=E='5I9`!R96%D;&EN:P!E>&5C=G``<W1R8VAR`&9P<FEN=&8`<F5A9&1I
M<C8T`&UE;6UO=F4`86-C97-S`'-T<F-M<`!?7VQI8F-?<W1A<G1?;6%I;@!?
M7V5N=FER;VX`;&EB8W)Y<'0N<V\N,0!?961A=&$`7U]B<W-?<W1A<G0`7V5N
M9`!?7VQI8F-?8W-U7V9I;FD`<&%R7V-U<G)E;G1?97AE8P!G971?=7-E<FYA
M;65?9G)O;5]G971P=W5I9`!P87)?8VQE86YU<`!P87)?8F%S96YA;64`<&%R
M7V1I<FYA;64`<&%R7VUK=&UP9&ER`%]?9&%T85]S=&%R=`!P87)?8W5R<F5N
M=%]E>&5C7W!R;V,`7U]L:6)C7V-S=5]I;FET`%]31$%?0D%315\`<&%R7VEN
M:71?96YV`'AS7VEN:70`<&%R7V9I;F1P<F]G`'!A<E]S971U<%]L:6)P871H
M`'!A<E]E;G9?8VQE86X`6%-?26YT97)N86QS7U!!4E]#3$5!4E-404-+`%A3
M7TEN=&5R;F%L<U]005)?0D]/5`!'3$E"0U\R+C(`1TQ)0D-?,BXP`$=,24)#
M7S(N,P!'3$E"0U\R+C,N,@!'3$E"0U\R+C0``````@`"``,``@`"``(``@`"
M`````@``````!``"``(````"``(````````````%``8``@````(``@``````
M`@`"`````@`"``0`!@`````````"``(``@`#``(````"``````````(``@`"
M```````$```````'`````@`"``<``P`'``,``@`"``@````!``$``0`!``$`
M`0`!``$``0`!``$``0````$``0`!``$``0`!`````0`"``$``0````$``0`!
M`````0`!`````0`!``(```'D````$````#`-:6D2````!@``!,0````0#6EI
M$`````,```3.```````!``4```(S````$``````-:6D3````"```!-@````0
M#6EI$@````<```3$````$`EI&7(````%```$X@```!`-:6D4````!```!.X`
M```0#6EI$`````(```3.`````!``-'(``#X&`````!``-'8``#X$`````!``
M-:(``#X&`````!``-<H``#X$`````!``.BX``#X&`````!``.GH``#X$````
M`!``.IH``#X&`````!``.IX``#X$`````!``.UX``#X&`````!``.V8``#X$
M`````!``.[X``#X$`````!``/`H``#X$`````!`!<2@``!X4`````!`!S?P`
M`%P3`````!`!S@```&,3`````!`!S@0``&83`````!`!S@@``%,3`````!`!
M<3@```$5`````!`!<3P```(5`````!`!<4````,5`````!`!<40```45````
M`!`!<4@```85`````!`!<4P```<5`````!`!<5````@5`````!`!<50```D5
M`````!`!<5@``$85`````!`!<5P```H5`````!`!<6````L5`````!`!<60`
M``P5`````!`!<6@```T5`````!`!<6P```X5`````!`!<7````\5`````!`!
M<70``!`5`````!`!<7@``!$5`````!`!<7P``!(5`````!`!<8```!,5````
M`!`!<80``!05`````!`!<8@``!45`````!`!<8P``!85`````!`!<9```!<5
M`````!`!<90``!@5`````!`!<9@``!D5`````!`!<9P``!H5`````!`!<:``
M`!L5`````!`!<:0``!P5`````!`!<:@``!T5`````!`!<:P``!X5`````!`!
M<;```!\5`````!`!<;0``"`5`````!`!<;@``"$5`````!`!<;P``"(5````
M`!`!<<```",5`````!`!<<0``"05`````!`!<<@``"45`````!`!<<P``"85
M`````!`!<=```"<5`````!`!<=0``"@5`````!`!<=@``"D5`````!`!<=P`
M`"H5`````!`!<>```"L5`````!`!<>0``%\5`````!`!<>@``"P5`````!`!
M<>P``"T5`````!`!<?```"X5`````!`!<?0``"\5`````!`!<?@``#`5````
M`!`!<?P``#$5`````!`!<@```#(5`````!`!<@0``#,5`````!`!<@@``#05
M`````!`!<@P``#85`````!`!<A```%H5`````!`!<A0``#@5`````!`!<A@`
M`#D5`````!`!<AP``#H5`````!`!<B```#L5`````!`!<B0``#P5`````!`!
M<B@``#T5`````!`!<BP``#\5`````!`!<C```$`5`````!`!<C0``$$5````
M`!`!<C@``$(5`````!`!<CP``$,5`````!`!<D```$05`````!`!<D0``$45
M`````)0A__!\"`*FD`$`%)/!``A"GP`%?\@"IC_>``$[WEJ4@![__"^```!!
MG@`(2`!$84@``T5(`$(=@`$`%'P(`Z:#P0`(."$`$$Z``""4(?_0?`@"II!A
M`!PX80`<D($`&#B!`!B0H0`4.*$`%)`!`#23P0`HD^$`+$@`1$4\@!``/&`0
M`#B$6_`X8UR@?(4C>#_@$`)(`$"I/2`0`HO)S@0OG@``0)X`*$@`0U4](!`"
M+X,``)!IWC1!G@',2`!"H8!_S@!(`$79F\,$W(!_S@!(`$7-B`,%'WQI&WB`
M?\X`8````I@)!1](`$6U@6$`'(DC!1\X"P`%82D``9DC!1\]($,PD2$`"#T@
M$`"0`0`,P`E?C#T@$`#)H0`(_:T`*,@)7Y`](!``_:T`*L@)7YC_C0``09T!
M.%0#$#H_X!`"2`!##8%!`!@]8!``.__.)("A`!Q\:1MX@`H``"^%``&0?Q`(
MD`,``#@+8L`]8!`!.6MR5)`#``0X"P`$/6`0`)`#``@X"V+$D`,`##@```20
M'Q`$0)T`'#@%__\Y8P`,?`D#IH0*``24"P`$0@#_^#BE``,Y8```@'\0$%2@
M$#H\@!``?6D!+CB$/41])DMX..```$@`0_E\?AMY08(`3(!_$!!(`$')/&`0
M`#AC8'!,QC&"2``<\2^#``!!G@`\@'\0$$@`06E(`$.5@`$`-'_#\WB#P0`H
M?`@#IH/A`"PX(0`P3H``((!_$!!(`$0A?'X;>$O__ZR`?Q`,+X,``$&>``Q(
M`#W52___N#Q@$``X8V`,3,8Q@D@`'(TO@P``D'\0#$&>_YQ+___</&`0`#R`
M$`(X8V&4.(3."$S&,8)(`$*=.&```4@`0A5\*0MX5"$`-C@```"4(?_P?`@#
MII`!```]`!``A:A?"$@`0C"4(?_@?`@"II.!`!`_@!`"D`$`)(@<SAR3H0`4
M+X```)/!`!B3X0`<0)X`8#^@$`$_P!`!.[UP"#O><`P_X!`"?]WP4($_SB!_
MWA9P.][__W^)\$!`G``L.__.(#DI``%5(!`ZD3\``'P=`"Y\"0.F3H`$(8$_
M``!_B?!`09S_X#@```&8',X<@`$`)(.!`!!\"`.F@Z$`%(/!`!B#X0`<."$`
M($Z``""4(?_P?`@"II`!`!2``0`4."$`$'P(`Z9.@``@?`@"II0A__`\8!`!
MD`$`%(`#<!`X8W`0+X```$&>`!P](```.`D``"^```!!G@`,?`D#IDZ`!"&`
M`0`4."$`$'P(`Z9.@``@E"'_\'P(`J:0`0`4@`$`%#@A`!!\"`.F3H``()0A
M_%!\;!MX.6,`.#A@``@X````?&D#II'!`V@Y(0#@D>$#;)(!`W"2(0-TDD$#
M>))A`WR2@0.`DJ$#A)+!`XB2X0.,DP$#D),A`Y2300.8DV$#G).!`Z"3H0.D
MD\$#J)/A`ZR!"P``@4L`!#EK``B1"0`$D`D``)`)``B120`,.2D`$$(`_^`X
M@`!`.2$!0'R)`Z8XH```.2D`"($)_]B!2?_<@6D``(`)``2`R?^H?0M:>(#I
M_ZQ]0`)X@0G_F'S+6GB!2?^<?.`">'T+6GB0J0`8?4`">%5K"#Q4``@^?`!;
M>)`)`!Q"`/^P@4$`X#R@6H([P```@6$`Y&"E>9D[0```@,P`(']2TWB`[``D
M@X$`Z(.A`.Q]:S@4?4HQ%($,`!A]1E-X@2P`''SK*A2"C``,?`LX$'P``1""
MK```?[U(%'^<012"`0#P5HGP/H(A`/16JB@T?```T(+,``A\P#(4@HP`$(*L
M`!16R_`"?Y;C>(+L``1].UMX?C&H%'X0H12`;``4@JP`#%;K*#Z##``<?7]3
M>'[]*A1\:Z@X@RP`$'WG^!1]QO$4?P"H>(*L``"#S``$?3VX$'TI21!_\2H4
M@($`_']*J#A_**AX?V?P.(.!`/A\9O!X?!-;>(!A`01]5$-X5JOP`E?*\#Y]
M*0#0?`^:%'U96WA_I"H4?7'X$'UK61!^R;(4?/4S>']H`'A^M;@4?I2Q%'P'
MR#B"@0$`?43H$'U*41"`@0$,5`DH/GX>@WA]:P#0?35*%%07\#Y^HRH4?1,[
M>'_+\A1]2@#0?2BX.#L```!]8Z@0?6M9$'__F!1_WI$4@&$!%%4O*#Y_BN(4
M?RI(>'P?>A15)_`^?_W8%'_<T12#00$(?V0J%'U10WA_$,-X?6L`T'XQ^!1^
M$/$4?`@X.#K```!]1-@0?4I1$("!`1Q^BZ(45`DH/G[K`'A],4H4?G7(%'Y4
MP12#`0$0?R,J%%0?\#Y]?4-X?MRS>'U*`-!^<^@4?E+A%'TH^#A]8\@0?6M9
M$(!A`215,2@^.,```']*TA1\ZDAX?!.*%'][N!1_6K$453WP/H+!`1A^Y"H4
M?55#>'S4,WA]:P#0?K78%'Z4T11\".@X?42X$'U*41!_"\(4@($!+'_K`'@[
MP```5`DH/GTU2A1\Y\@4?,;!%(,!`2!_(RH45!OP/GUS0WA_TO-X?4H`T'YS
M.!1^4C$4?2C8.'UCR!!]:UD0@&$!-%4Q*#Y^RK(4.X```'^J2'A\$XH4?_^X
M%'_>L115)_`^@L$!*'[D*A1]54-X?Y3C>'UK`-!^M?@4?I3Q%'P(.#A]1+@0
M?4I1$'\+PA2`@0$\?VL`>#M```!4"2@^?35*%'^]R!1_G,$4@P$!,'\C*A14
M'_`^?7-#>']2TWA]2@#0?G/H%'Y2X11]*/@X?6/($'UK61"`80%$53$H/G[*
MLA0XP```?.I(>'P3BA1_>[@4?UJQ%%4]\#Z"P0$X?N0J%'U50WA\U#-X?6L`
MT'ZUV!1^E-$4?`CH.'U$N!!]2E$0?PO"%("!`4Q_ZP!X.\```%0)*#Y]-4H4
M?.?(%'S&P12#`0%`?R,J%%0;\#Y]<T-X?]+S>'U*`-!^<S@4?E(Q%'THV#A]
M8\@0?6M9$(!A`515,2@^?LJR%#N```!_JDAX?!.*%'__N!1_WK$452?P/H+!
M`4A^Y"H4?55#>'^4XWA]:P#0?K7X%'Z4\11\"#@X?42X$'U*41!_"\(4@($!
M7']K`'@[0```5`DH/GTU2A1_O<@4?YS!%(,!`5!_(RH45!_P/GUS0WA_4M-X
M?4H`T'YSZ!1^4N$4?2CX.'UCR!!]:UD0@&$!9%4Q*#Y^RK(4.,```'SJ2'A\
M$XH453WP/G][N!1_6K$4@L$!6'[D*A1]54-X?-0S>'UK`-!^M=@4?I31%'P(
MZ#A]1+@0?4I1$'\+PA2`@0%L?^L`>#O```!4"2@^?35*%%0;\#Y\Y\@4?,;!
M%'US0WB#`0%@?R,J%'_2\WA]2@#0?G,X%'Y2,11]*-@X.X```'UCR!!]:UD0
M53$H/H!A`71^RK(4?ZI(>'P3BA1__[@4?]ZQ%%4G\#Z"P0%H?N0J%'U50WA_
ME.-X?6L`T'ZU^!1^E/$4@H$!>'P(.#@[0```?42X$'U*41"`@0%\5`DH/G\+
MPA1_:P!X?35*%'\YZ!1_&.$4@X$!<'^C*A14'_`^?7-#>']2TWA]2@#0?G/(
M%'Y2P11\ZTAX@D$!@'T#Z!!]"$$0@&$!A%4U*#XXP```?LJR%'TJ^#A\$ZH4
M?O?8%'[6T11^I"H4@T$!C%4Y\#Y]<5-X?-`S>'T(`-!^,;@4?A"Q%'_J`'A]
M9*@0?6M9$%03*#Z`@0&(?XCB%#O```!\",@X/V!NV7TQFA1C>^NA?.?H%'S&
MX114%_`^?4]#>'_.\WB!`0&4?6L`T'YCVA1][S@4?<XQ%'TJN#A^BZ(4.P``
M`'\K2'A5)2@^52?P/GU]4WA]+RH4?`.8$'P``1!_',-X@&$!G'__J!1_WJ$4
M?+K:%'__Z!1_WN$453$H/H/!`9!\``#0.,```'SJNGA]>B@0?6M9$'Y`DA2#
M00(,?!^*%#K```!_Z-H4?SF8%'\8D115/?`^?-2R>'U52GA]:P#0?2CX$'TI
M21!^M<@4?I3!%($!`:1_JCIX.X```%01*#Y\BR(4?2D`T'[W*!1^UB$4@($!
MF'RCVA14&?`^?76*%'^2,GA]4P)X?\GR%'YSN!1^4K$4?_\X%'_>,12`P0&@
M?.C:%'\JZG@[````?`,H$'P``1!5<2@^@&$!K%5W\#Y],XH4?Q3B>'U56GA\
M``#0?6@X$'UK61!^M?@4?I3Q%($!`;1^ZLIX.L```%4Q*#Y\@"(4?6L`T'^]
M*!1_G"$4@($!J'RCVA15/_`^?!6*%'[2PGA]4TIX?,LR%'YSZ!1^4N$4?SDX
M%'\8,12`P0&P?.C:%'_JNG@[P```?2,H$'TI21!4$2@^@&$!O%0=\#Y]<XH4
M?]2R>'U5`GA]*0#0?`@X$'P``1!^M<@4?I3!%($!`<1_JOIX.X```%5Q*#Y\
MB2(4?```T'[W*!1^UB$4@($!N'RCVA15>?`^?36*%'^2\GA]4UIX?,`R%'YS
MN!1^4K$4?_\X%'_>,12`P0'`?.C:%'\JZG@[````?6,H$'UK61!5,2@^@&$!
MS%4W\#Y\$XH4?Q3B>'U52GA]:P#0?2@X$'TI21!^M?@4?I3Q%($!`=1^ZLIX
M.L```%01*#Y\BR(4?2D`T'^]*!1_G"$4@($!R'RCVA14'_`^?76*%'[2PGA]
M4P)X?,DR%'YSZ!1^4N$4?SDX%'\8,12`P0'0?.C:%'_JNG@[P```?`,H$'P`
M`1!5<2@^@&$!W%5]\#Y],XH4?]2R>'U56GA\``#0?6@X$'UK61!^M<@4?I3!
M%($!`>1_JOIX.X```%4Q*#Y\@"(4?6L`T'[W*!1^UB$4@($!V'RCVA15.?`^
M?!6*%'^2\GA]4TIX?,LR%'YSN!1^4K$4?RKJ>#L```!](R@0?2E)$(!A`>Q4
M$2@^?_\X%'_>,11\Z-H4@,$!X%07\#Y_%.)X?7.*%'U5`GA]*0#0?`@X$'P`
M`1!__Z@4?]ZA%($!`?2#P0'H.L```'[JRGA5<2@^?(DB%'P``-!5=?`^?3^*
M%'[2PGA_X]H4?5-:>'^]*!1_G"$4?,`R%'^]F!1_G)$4.H```'ZJNGA]8_@0
M?6M9$(!A`?Q5,2@^?SDX%'\8,11\Z-H4@,$!\%4S\#Y^A+)X?!V*%'U%2GA]
M:P#0?2@X$'TI21`Z0```@0$"!'\Y*!1_&"$4?FJJ>%0%\#Y4$2@^?\OR%'TI
M`-!]>8H4.(```'\_N!1_'K$4?ERB>(/!`?A_X]H4?5T">'S),A1\JIIX?[W(
M%'^<P11\YZ@4?,:A%'P#^!!\``$057$H/GR6DGA]5UIX?3V*%'[W.!1^UC$4
M@,$"`%5Y\#Y\Z-H4?```T'\C*G@[````52LH/G_`\A1\"#@0?``!$'\<(GA]
M%UH4?'U*>'U_F!1]7I$4?```T%4_\#Y_O5@4?YQ1%#O```!5"R@^?,`R%#D@
M``!_X,IX?.<H%'S&(11_RL)X@*$"%)$A`!A]/5H4?`M">("!`APZP```?Z=8
M%'^&411]>MH4@4$""'P:6!!\``$0@N$")'P``-"2P0"850?P/GU`4A2"P0(@
M?SE8%'\8410XP```?.#Z>%4K*#Y\RO)X?1U:%'P+2GA_N5@4?YA1%'UEVA2!
M00(0?`58$'P``1!\``#053GP/GU`4A1__U@4?]Y1%'\@.G@[````50LH/CE`
M``!]/5H4D4$`D'P+0GA_"C)X.T```'^_6!1_GE$4?63:%(%!`AA\!%@0?``!
M$)-!`(A\``#0?4!2%%4?\#Y\JS@4?(HQ%%4K*#Y\_5H4.\```'_@RG@_H(\;
M.X```&.]O-Q_RL)X?`M*>#J```!_95@4?T11%'U]N!1]7+$4@T$"F)*!`*!_
M.5@4?QA1%(%!`HA5)?`^@6$"C'R@^W@X@```?*/X.'T]6!1]'%$4@4$"D'S@
M`#B!80*4.H```)$!`,@Z0```.<```'[]6!1^W%$4@0$"*%3K*#Z1(0#,?-M:
M%($A`BPZ````@V$"G'U]2!1]7$$4DL$`T%3I\#Z2X0#4?OW8%'[<T11_:_@4
M?TKQ%(/A`C1\BO`X@\$",'P+&WA]("MXDL$`V'\Y6!1_&%$45,LH/I+A`-Q\
M^5H4@P$"@'U]^!1]7/$4.0```(,A`H1](R@X?,``.#K````ZX```?^LH%'_*
M(122P0"H5,7P/H+!`CA]"B`X?`L;>)+A`(""X0(\?WM8%']:411\H$MX5.LH
M/GS;6A0X@```?WW(%']<P11]?;@4?5RQ%)-!`,!\HT@X?.``.)-A`,1_:T@4
M?TI!%(,!`D!4Z?`^?(I`.(,A`D1\"QMX?2`K>'__6!1_WE$45,LH/GS_6A0Y
M````?7W(%'U<P11](R@X?,``.#O```"3P0!X?^LH%'_*(11]"B`X?`L;>'][
M6!1_6E$45.LH/H-!`GA4Q?`^?-M:%(-A`GQ\H$MX.(```'RC2#A]?=@4?5S1
M%(-!`DA\X``X@V$"3#L```"100"X.L```)%A`+Q]?=@4?5S1%']K2!1_2D$4
M?(I`.'P+&WA4Z?`^?_]8%'_>4114RR@^@\$"4'S_6A2#X0)4?2`K>#E````Y
M````?2,H.)%!`'!\P``X?7WX%'U<\11_ZR@4?\HA%'T*(#B3P0`H?`L;>)/A
M`"Q4Q?`^?_M8%'_:412#00)P?*!+>(-A`G1\XP`X@\$"6#B```!]?=@4?5S1
M%)!A`&Q\HT@XD6$`M%3K*#Y\WUH4@^$"7#M```"100"P?7WX%'U<\11_ZT@4
M?\I!%)/A`&1\BD`X@^$`;)/!`&!_ZQMX@\$`*(/A`"Q]/U@4?1Y1%%3_\#Y4
MRR@^..```'_@*WB0X0`(?.E:%#O```!4Z"@^@2$"9'_C*#B1`0`,?,``.%3[
M\#Z!`0)@?7U(%'U<011]*R@4?0HA%'_*(#B`@0!D?`L;>(!A`&"1(0`L5,GP
M/GUK(!1]2AD4@($`#'T@^WA\Y@`XD0$`*'UK(A1]*O@X564H/E5Y\#Z0H0!T
M?V!+>#D```"`H0#`?6``.)#!`&"`P0#$@.$";'R&R!1\9<$4@,$":)%!`&Q]
M?3@4?5PQ%(#!`+"`X0"T?6OX%'U*\12080#`?V-(.)"!`,1\`QMX?*=(%'R&
M011_1T`XD&$`))#A`"!_(-MXD*$`M(#!`"2`H0`@D($`L(#A`&!\BS`4?&HI
M%'T&\#B!`0!LD,$`$'SG0WB0@0`DD.$`%(/!`"B#X0`L@($`%)!A`""`80`0
M@,$`)'U_(!1]7AD4@($`=(#A`-1]*R(4524H/E4W\#Y]9BH4@,$`T'TC`#A5
M=?`^56@H/I"A`'Q_YZ@4?\:A%)$!`(1^X,MX@.$`N'U@`#B!`0"\?NG(.'\E
MV#A\"4MX?&4K>'UHV!1]1]$4?LC`.)$!`#B1(0`\@,$`.)"A`#1^A;`X@.$`
M/(,A`+1]*S@4?0HQ%'\'T#B#80`TD.$`,(,!`+"0H0!`@T$`,(!A`,A]>=@4
M?5C1%(-A`(2#`0#`?0O:%(,A`,15`"@^@T$`0%43\#Y\Z0(4D`$`C'Z@NWA]
M```X?JFX.'P)2WA4Y"@^D2$`1'YIJ#A4\?`^D($`E(-A`$1]>=@4?5C1%'S+
M(A2`@0#,5,`H/E3/\#Z0`0"<?F"K>'UDN!1]0[$4?.``.(*A`-Q^1*`X?`E+
M>(*!`-B0@0!(?>"+>'X6D#B1(0!,?S68%'\4D11]U8`XDJ$`6#B```"`X0!(
M@0$`3)+!`%!]:T`4?4HY%($!`)Q]*T(4?>N(.'T@`#A5*B@^?`M;>'X@FWB1
M00"D?,8`.'X@F#B180!<52GP/GS``WB1(0`<?3=+>'TC>WB0`0!4?O2[>(-!
M`%"#80!4@L$`&'U_V!1]7M$4@V$`I(%!`J!^VG`X?`O:%(%A`J2#P0!85`7P
M/H/A`%Q\_5@4?-Q1%'[K>#B"00*P?3GX%'T8\11_)X@4?P:!%(#!`JB`X0*L
M5!\H/GP`&#B!`0`8?!M;>'TI^A23X0"L?*"[>%4_\#Z"80*T?SG8%'\8T11\
MJZ`X@H$`&']].!1_7#$4@@$"N%4W*#Z"(0*\?2D`.'R&0#A\&;H4?2=;>'[[
M>!1^VG$4?^DK>('!`L!^]S@4?M8Q%('A`L14%2@^5!OP/GP)2#A\%ZH4@J$`
M'#O```!\_9@4?-R1%'_K*#A\YZ@4?,:A%'_8(#A].5MX?VG[>'YGR!1^1L$4
M?VOX.'\]B!1_'($4@@$"R#M```""(0+,?`E(.#S@RF(XP```8.?!UE0=\#Y\
MI<@4?(3!%']6\#A]-UMX5!4H/GP3JA1^]R@4?M8A%'^HVGA\IW@4?(9Q%#N`
M``"!P0+0?XK2>('A`M14&?`^?*7X%'R$\11]"P)X@0P`(%0)*#Y^95@4?D11
M%'TW2A1\IX@4?(:!%'\KZGB"`0+8.P```((A`MQ_>R@4?UHA%'\6XGA5/_`^
M?7=*>%4U*#Y\$ZH4?^O*>'Z[N!1^FK$4.\```'[G>!1^QG$4@<$"X'^]N!1_
MG+$4@>$"Y'_$PGA4&_`^?64">%0)*#Y^?2@4?EPA%'TU2A1\IX@4?(:!%']K
M^GB"`0+H.T```((A`NQ_.2@4?Q@A%']6\GA5/?`^?7=*>%4U*#Y\$ZH4?ZO:
M>'ZYN!1^F+$4.X```'[G>!1^QG$4@<$"\'__N!1_WK$4@>$"]'^$TGA4&?`^
M?64">%0)*#Y^?R@4?EXA%'TU2A1\IX@4?(:!%'\KZGB"`0+X.P```((A`OQ_
M>R@4?UHA%'\6XGA5/_`^?7=*>%4U*#Y\$ZH4?^O*>'Z[N!1^FK$4.\```'[G
M>!1^QG$4@<$#`'^]N!1_G+$4@>$#!'_$PGA4&_`^?64">%0)*#Y^?2@4?EPA
M%'TU2A1\IX@4?(:!%']K^GB"`0,(.T```((A`PQ_.2@4?Q@A%']6\GA5/?`^
M?7=*>%4U*#Y\$ZH4?ZO:>'ZYN!1^F+$4.X```'[G>!1^QG$4@<$#$'__N!1_
MWK$4@>$#%'^$TGA4&?`^?64">%0)*#Y^?R@4?EXA%'TU2A1\IX@4?(:!%'\K
MZGB"`0,8.P```((A`QQ_>R@4?UHA%'\6XGA5/_`^?7=*>%4U*#Y\$ZH4?^O*
M>'Z[N!1^FK$4.\```'[G>!1^QG$4@<$#('^]N!1_G+$4@>$#)'_$PGA4&_`^
M?64">%0)*#Y^?2@4?EPA%'TU2A1\IX@4?(:!%']K^GB"`0,H.T```((A`RQ_
M.2@4?Q@A%']6\GA5/?`^?7=*>%4U*#Y\$ZH4?ZO:>'ZYN!1^F+$4.X```'[G
M>!1^QG$4@<$#,'__N!1_WK$4@>$#-'^$TGA4&?`^?64">%0)*#Y^?R@4?EXA
M%'TU2A1\IX@4?(:!%'\KZGB"`0,X.P```((A`SQ5/_`^?WLH%']:(11_%N)X
M?7=*>%4U*#Y\$ZH4.\```'Z[N!1^FK$4?^O*>'[G>!1^QG$4@<$#0'^]N!1_
MG+$4@>$#1'_$PGA4&_`^?64">%0)*#Y^?2@4?EPA%'TU2A1\IX@4?(:!%']K
M^GB"`0-0.T```((A`U15/?`^?SDH%'\8(11_5O)X?7=*>%4U*#Y\$ZH4.X``
M`'ZYN!1^F+$4?ZO:>(*!`UA^YW@4?L9Q%'[W^!1^UO$4?X32>'UE`GA4"2@^
M?G<H%'Y6(12"P0-(5!GP/H+A`TQ]-4H4.P```'\KZGA\I[@4?(:Q%%4U*#Y\
M$ZH4@J$#7'\>XGA5-_`^?7]*>'][*!1_6B$4?NO*>#K```!_>_@4?UKQ%%0)
M*#Y_YX@4?\:!%'T[2A1__^@4?][A%'[$PGA]90)X5!WP/G]_*!1_7B$452LH
M/H-,``Q\NUH4?Z"Z>'UGJ!1]1J$4.X```#B```!\Z\@4?,K!%(,,``!_GK)X
M@RP`!'P?2GA4JR@^5(`H-'__.!1_WC$4@\P`&'U[`WA]?]H4.4```(-L`!1]
M:\@4?4K!%(,L``A5)_`^@^P`'#C```!\I=`4?(3)%($L`"0X````@TP`$'^]
M^!1_G/$4?O=(%'[60120#```?.?8%'S&T121;``$D`P`")"L``R0#``0D.P`
M%)`,`!B3K``<D`P`()+L`"2!P0-H@>$#;((!`W""(0-T@D$#>()A`WR"@0.`
M@J$#A(+!`XB"X0.,@P$#D(,A`Y2#00.8@V$#G(.!`Z"#H0.D@\$#J(/A`ZPX
M(0.P3H``()0A_]!\"`*FDX$`('Q\&WDX8```DT$`&'R:(WB0`0`TDV$`').A
M`"23P0`HD^$`+$&"`)@](```@VD``"^;``!!G@"(B!P``#N@```O@```09X`
M,"^``#U!G@`H?XGC>'^=XWB,"0`!.[T``2^````O```]09X`"$":_^Q_O.A0
M@_L``#A@```OGP``09X`/']^VWA_X_MX?X3C>'^EZWA(`"@E+X,``$">`!!\
M'^BN+X``/4&>`#R'_@`$+Y\``$">_]0X8```@`$`-(-!`!A\"`.F@V$`'(.!
M`""#H0`D@\$`*(/A`"PX(0`P3H``('_;\%`X?0`!?]X6<'Q_&A23V@``@`$`
M-(-!`!A\"`.F@V$`'(.!`""#H0`D@\$`*(/A`"PX(0`P3H``()0A_^!\"`*F
M.($`')`!`"1,QC&"2__^P8`!`"0X(0`@?`@#IDZ``""4(?_0?`@"II`!`#23
MP0`H/\```)/A`"Q\?QMX?^/[>#B!`!Q,QC&"2__^A2^#``!!G@!0@`$`'(%^
M``!4`!`Z?2L"%(%)``0OB@``?4L!+D&^_\PY*0`$A`D`!"^```"0"?_\0)[_
M]'_C^W@X@0`<3,8Q@DO__CDO@P``0)[_N(`!`#2#P0`H?`@#IH/A`"PX(0`P
M3H``()0A_^!\"`*FD^$`'#_@$`*`?\X`D`$`)).A`!23P0`82``FV8$C`82`
M?\X`@\D`!$@`)LF+HP34@'_.`%>]!GY(`":Y@2,`!(`)`!!4`(0P?[T#>+.^
M``*`?\X`2``FG8$C`82`?\X`@\D`!$@`)HT\@!``.*```#B$8KQ(`"3MD'X`
M'(!_S@!(`"9Q@2,!A(!_S@"#R0`$2``F88`#!=2`?\X`D!X`($@`)E&!(P&$
M@'_.`(/)``1(`"9!.````($C"`0OB0``09X`%(!_S@!(`"8I@2,(!(`)`'"0
M'@`D.\```(!_S@!(`"81@2,!A(!_S@"!*0`$D\D`*$@`)?V!(P&$@'_.`($I
M``23R0`82``EZ8$C`82`?\X`@^D`!$@`)=F``P&,D!\`+(`!`"2#H0`4?`@#
MIH/!`!B#X0`<."$`($Z``""4(?]@?`@"II/A`)Q\?QMYD`$`I)-A`(R3@0"0
MDZ$`E)/!`)A!@@`0B!\``"^```!`G@`H@`$`I(-A`(Q\"`.F@X$`D(.A`)2#
MP0"8@^$`G#@A`*!.@``@2``EF7Q^&WE!HO_4/X`0`#N<7Z!_P_-X2``E`7QI
M&WE_X_MX.VD`$T&"`)2("0`3+X``+D&>`+Q(`"-1?'T;>']CVWA(`"-%?'T:
M%#AC``)(`"+9?X3C>'_E^WA\?1MX?V;;>$S&,8)(`"2!?Z3K>#BA`!@X8``#
M2``DT2^#__]_H^MX09X`%(`!`"A4``0F+X!``$&>`(!(`"'!?Z/K>$@`(2E_
MP_-X2``D<7QI&WE_X_MX.VD`$T""_W1_P_-X2``DR7_C^WA(`"%!@`$`I(-A
M`(Q\"`.F@X$`D(.A`)2#P0"8@^$`G#@A`*!.@``@B`D`%"^```!!GO\<+X``
M+D"^_SB("0`5+X```$&>_PA+__\H2__^E4O__X24(?_@?`@"II/A`!P_X!`"
MD\$`&'Q^&WB`?\X`D`$`)).A`!1(`"09?\3S>#N@```XHP!@.&```T@`)!4O
M@P``09X`)(`!`"1_H^MX@Z$`%'P(`Z:#P0`8@^$`'#@A`"!.@``@@'_.`$@`
M(]6``P!P5``$)B^`0`!!G@`@@'_.`$@`([V!(P!P52D$)FT@__\O@*``0)[_
ML'_#\W@X@``"2``B[8`!`"1\?0`T@\$`&'P(`Z97O=E^@^$`''^CZWB#H0`4
M."$`($Z``""4(?_`?`@"II.!`#"3H0`TD\$`.)/A`#Q\?QMXD`$`1),!`""3
M(0`DDT$`*)-A`"R(!```:!T`/2.]``!_I`&4?Z/K>$@`(5TX@0`<?'P;>'_C
M^WA,QC&"2__Z-7Q^&WE!@@%,2``A/3O>__\Y/?__?YP80$"=`12#00`</V``
M`%=:$#J('P``.2```"^```!!G@`T+X``/4&>`"Q_Z_MX?^G[>$@```A!F@`8
MC`L``3DI``$O@```+P``/4">_^Q]/TA0.'P``H/;``!\8TH42``@<3@`__\O
M@P``?'[1+D&>`'2('P``/2```(%I```O@```@2$`'%4I$#I]*T@NF`D``$&>
M`#`O@``]09X`*'TK2WA(```(09H`'(P?``$Y*0`!+X```"\``#V<"P`!0)[_
MZ#@``#T[O?__F`D``(P=``$O@```G`D``4">__0X````?`,#>(`!`$2#`0`@
M?`@#IH,A`"2#00`H@V$`+(.!`#"#H0`T@\$`.(/A`#PX(0!`3H``((P)``$O
M@```G!X``4&^_[R,"0`!+X```)P>``%`GO_D2___J#]@```X@``(@QL``#O`
M``"`&```+X```$&>`"!_"<-XA`D`!#O>``$O@```0)[_]#B>``)4A!`Z/2`0
M`H`)SB0O@```09X`/'\#PWA7VA`Z2``?-3@`__\O@P``?'D;>)![``!!OO]$
M.!X``3D@``!4`!`Z?3D!+I/!`!Q+__Y<.````7R#(WB0"<XD2``?"3@`__]\
M>1MY0:+_$%?:$#I_!,-X?T73>$@`'7V3.P``2___N)0A[]!\"`*F.*`/_Y.A
M$"1\G2-X.($`')/!$"A\?AMX/&`0`)`!$#0X8U^HD^$0+(`"C_B0`1`<.```
M`$@`'@4L`P``0($`C#@!$"`[X___?2#Z%(@)[_PO@```09X`;'Q_&W@X80`<
M.(``+W_E^WA(`!^1+X,``$&>`%@](!`"@&G.`$@`((U_Q/-X.*$`''_F^WA(
M`"`=@2$0'(`"C_A]*0)Y.````$""`$2``1`T@Z$0)'P(`Z:#P1`H@^$0+#@A
M$#!.@``@+Y\``$">_Y@](!`"@&G.`$@`(#E_Q/-X?Z7K>$@`'6U+__^P2``=
M!90A__!\"`*F/2`0`H!IS@"0`0`42``@#3R`$``\H!``/,`0`#B$7[@XI5G`
M.,9?U$@`'H&``0`4."$`$'P(`Z9.@``@E"'_X'P(`J:3X0`</^`0`H!_S@"0
M`0`D2``?Q4O__Z&`?\X`2``?N3S`$``\@!``.,9BO#R@$``XA%_@.*52D'S'
M,W@Y````2``>U8`!`"2#X0`<."$`('P(`Z9.@``@E"'?T'P(`J:3X2`L.^``
M`)`!(#23P2`H@`*/^)`!(!PX````2``<^3R`$``\P!``?&4;>#B$7_@X80`4
M.,9@!$S&,8)(`![)+X,``$&<`$`X80`4.($0&#B@$`!(`!Q1?'X;>4&``"@X
M?@`!2``<X7Q_&WE!@@`8.($0&'_%\WA(`!M].````'P?\:Z!(2`<@`*/^'TI
M`GDX````?^/[>$""`!R``2`T@\$@*'P(`Z:#X2`L."$@,$Z``"!(`!NAE"'_
M\#@A`!!+__\XE"'OL'P(`J9]@``FDZ$01)/!$$A\?AMX/&`0`)/A$$PX8V`,
M?)\C>)&!$""0`1!4DJ$0))+!$"B2X1`LDP$0,),A$#2301`XDV$0/).!$$"`
M`H_XD`$0'#@```!,QC&"2__VF3B``"]\?1MX?\/S>$@`'%$O@P``09X`=#Q@
M$`!_Q/-X.&-@&$S&,8)+__JU@2$0'(`"C_A]*0)Y.````'_#\WA`@@&D@`$0
M5(&!$"!\"`.F@J$0)(+!$"A]@($@@N$0+(,!$#"#(1`T@T$0.(-A$#R#@1!`
M@Z$01(/!$$B#X1!,."$04$Z``"!_P_-X/V`0`$@`&^T[>V`H?'H;>']DVWA_
MX_MX2``="7QU&WE!HO]L+AT``#\`$``_(!``.L```#[@$``[&&`L.SE@-#^`
M$`)BUH``.^```(@5```O@```0)X`"#JW8`A!D@`8?Z/K>'ZDJWA(`!F)+X,`
M`$&>`)A^HZMX2``;>7TU&A2("?__+X``+T">`!B?Z?__.&/__X@)__\O@``O
M09[_\#AC``%\8](4+X,/_T&]_N!_!,-X?J6K>'\FRWA_Q_-X.&$`'$S&,8)(
M`!R)@'S.`$@`'/$X@0`<.*,`8#A@``-(`!S1+X,``$">`!R`?,X`2``<T8`#
M`'!4``0F?X"P`$&>`"`X8```?V3;>$@`'!4O@P``?'4;>$">_S1+__YP.&$`
M'#B```%(`!OI+X,``$">_]0\8!``.($`'#AC8!A,QC&"2__Y#3AA`!Q(`!LU
M?'X;>$O__DQ(`!E)E"'_\(@#```O@```09X`/#DC``%\:QMX2```%(P+``$Y
M*0`!+X```$&>`"`O@``O0)[_[(P+``%](TMX.2D``2^```!`GO_H."$`$$Z`
M`""4(?_@?`@"II/!`!A\?AMYD`$`))/A`!Q!@@#@B!X``"^```!!G@#42``:
M'3AC__]\OAH4?QXH0'^%\`!`F``X?!X8KB^``"]`G@#@?!XH4'RI*WA\"0.F
M2```$(P)__\O@``O0)X`Q#BE__]_A?``0@#_[$&>`/0X!?__?*DK>'^>`$!\
M'BA0?`D#ID&=`1POGO__09X!%#BE__]"0``0C`G__R^``"]!GO_P?+XH4#A@
M```X!0`"*X`0`$&=`"0_X!`"?\3S>#O_SB0XI0`!._\`!'_C^WA(`!I-?^/[
M>(`!`"2#P0`8?`@#IH/A`!PX(0`@3H``(#A@``)(`!CI+`,``$&B_]PX`"X`
ML`,``(`!`"2#P0`8?`@#IH/A`!PX(0`@3H``(#@%__]\J2MX?YX`0'P>*%!\
M"0.F09T`>"^>__]`O@`42```;(P)__\O@``O09X`##BE__]"`/_P?X7P`$O_
M_Q"(!0``+X``+T&>`!0\8!``.&-@-$@`&5E+__]@.&```D@`&%U\:1MY.&``
M`$&B_TPX`"X`?2-+>+`)``!+__\\.````7P)`Z9+__[H.````7P)`Z9+__^<
ME"'_L'P(`J8\@!``.*``(CB$7QR3@0!`.&$`&#^`$`"3H0!$/Z`0`#N<8(B3
MP0!(.[U@##_`$`"3X0!,/^`0`#O>8'R0`0!4._]@8(`"C_B0`0`\.````$@`
M%GT\8!``.&-@.$S&,8)+__)=/&`0`#AC8$1,QC&"2__R33Q@$``X8V!,3,8Q
M@DO_\CT\8!``.&-@6$S&,8)+__(M?^/[>$S&,8)+__(A/&`0`#AC8'!,QC&"
M2__R$7^CZWA,QC&"2__R!7_#\WA,QC&"2__Q^7^#XWA,QC&"2__Q[3Q@$``X
M8V"43,8Q@DO_\=T\8!``.&-@&$S&,8)+__'-/&`0`#AC8*!,QC&"2__QO3Q@
M$``X8V"L3,8Q@DO_\:T\8!``.&-@N$S&,8)+__%U?&0;>4&"`!!_@^-X3,8Q
M@DO_]:D\8!``.&-@S$S&,8)+__%1?&0;>4&"`!0\8!``.&-@X$S&,8)+__6!
M/&`0`#AC8.Q,QC&"2__Q*7QD&WE!@@!8?Z/K>$S&,8)+__5=/(`0`'_C^W@X
MA&$<3,8Q@DO_]4F!(0`\@`*/^'TI`GDX````0((`?(`!`%2#@0!`?`@#IH.A
M`$2#P0!(@^$`3#@A`%!.@``@/&`0`#AC8/Q,QC&"2__PO7QD&WE!@@`4?\/S
M>$S&,8)+__3Q2___E#R`$``X80`I.(1A$#B@``I(`!@I+X,``$">_WA_P_-X
M.($`,TS&,8)+__3!2___9$@`%0F4(?_@?`@"II/A`!P_X!`!@']R5)`!`"0O
M@___09X`&(`!`"2#X0`<."$`('P(`Z9.@``@/&`0`#AC8'Q,QC&"2__P+7QI
M&WDX8```08(`'(@)```O@```09X`$&@#`#!\8P#05&,/_H`!`"20?W)4?`@#
MIH/A`!PX(0`@3H``()0A__!\"`*FD`$`%$@`%(E(`!/E?&D;>3A@``!!@@`(
M@&D``(`!`!0X(0`0?`@#IDZ``""4(?^P?`@"ICT@$``Y*5\<DZ$`1'Q]&WB3
MX0!,D`$`5),A`#2300`XDV$`/).!`$"3P0!(@`D`)(#)`"A\'P-Y@.D`+($)
M`#"!20`T@6D`.($I`#R0`0`4D,$`&)#A`!R1`0`@D4$`))%A`"B1(0`L08(`
M=#]@$``_@!``.\$`%#M[8"P[G&`H2```'$@`$P4O@P``09X`?(?^``0OGP``
M09X`1'_C^WA,QC&"2__O#7^DZWA\>1MY08(`$(@9```O@```0+[_R'_C^WA_
MI.MX3,8Q@DO_\RV'_@`$+Y\``$">_\2``0!4@R$`-'P(`Z:#00`X@V$`/(.!
M`$"#H0!$@\$`2(/A`$PX(0!03H``('^CZWA(`!2-?'H;>'\CRWA(`!2!?'H:
M%#AC``)(`!05?V3;>'^EZWA\>AMX?X;C>'\GRWA,QC&"2``5N7_C^WA_1--X
M3,8Q@DO_\JE+__\\/`#__WPL"WA@`'ZP/2`0`'PA`6Y\"`*F.2E?'),L_^1\
M>1MXDXS_\#^`$`"0#``$.YQ@#)(L_\1_@^-XDDS_R))L_\R2C/_0DJS_U)+,
M_]B2[/_<DPS_X)-,_^B3;/_LDZS_])/,__B3[/_\@^D`3(")`%"`J0!4@,D`
M6(#I`%R!"0!@@4D`9(%I`&B`"0!L@ZD`1(/)`$B#"0!`/2$``8(BC_B2*8$,
M.B```),!`#"3X0`8DZ$`-)/!`#B0@0`<D*$`()#!`"20X0`HD0$`+)%!`#R1
M80!`D`$`1$S&,8)+_^UY?'\;>4&"`!"('P``+X```$">!#A+__UU?'@;>4&"
M!$"+^```+Y\``$&>`#1(`!51?PG#>#E``%^!8P``5_\(/'P+^BYP$P@`0((`
M")E)``"/Z0`!+Y\``$">_^"`80`8+X,``$&>`%`[X0`82```$(1_``0O@P``
M09X`/$S&,8)+_^SU?'X;>4&B_^B('@``+X```$&>_]Q+__!9+X,``$&>_]!_
MP_-X2``317QW&WE`@@!\@^$`,#K@```OGP``09X`;(@?```[P``!+X```$"^
M`#Q(``!8.````%?)$#I@`($0?``*%'T@2A0]*?__@^E_("^?``!!G@&(B!\`
M`#O>``$O@```09X!>'_C^WA+_^_A+X,``$&>_\!_X_MX2``2S7QW&WE!@O^P
M?N.[>#^@$`!(`!(I.[U@-'Q_&WA_`\-X2``2&7__&A0[_P0$?^/[>$@`$:D\
M@!``/.`0`'Q^&W@XA&$H?N6[>'^FZW@XYV$T?PC#>$S&,8)(`!-!?\/S>#B`
M`<!(`!)5+X/__T&>`+@_`!`"@'C.`$@`$Y%_Q/-X.*,`8#A@``-(`!.1+X,`
M`$&>`-0](!`"@+D``#R`$`"`:<W\.(1AQ'_&\W@[X```3,8Q@D@`$:4\P0`!
M?^/[>(#F@0R`PH_X?.<R>3C```!`@@BD@6$``(`+``2"*__$?`@#IH)+_\B"
M:__,@HO_T(*K_]2"R__8@NO_W(,+_^"#*__D@TO_Z(-K_^R#B__P@ZO_](/+
M__B#Z__\?6%;>$Z``"!(`!'%@.,``"^'`!%!GO]`/2`0`H"Y```\@!``@&G-
M_#B$83Q_QO-X.^```$S&,8)(`!$%2___8#K@``!+__ZH@'C.`$@`$J&``P!P
M5``$)B^`0`!`GO\<@'C.`$@`$HF"XP!X2``/<7^7&`!`GO\$@'C.`$@`$G&`
M`P!P5``%_B^``<!`GO[L?^/[>$@`$"E\?QMX/&`0`#AC8NA,QC&"2__JC2^#
M``!!G@'@@QD``$@`$/5\9!MX?P/#>$O_\WE\>!MY08(!Q'\#PWA(`!!)+X,`
M`WQW&WA`G0`X.&/__#R`$`!\>!H4.(1A>$@`#BDO@P``0)X`'"^7``1!G@9(
M?OBZ%(@7__LO@``O09X&.$O_^;$O@P``0)X`''\#PW@X@```3,8Q@D@`$!U\
M>1MY0((!8#R`$``\8!``.(1A'#AC8'P_(!``3,8Q@DO_[BD_8!``2``/,3LY
M8KP\@!``?&<;>#B$8:!_X_MX?\7S>'^FZWA_*,MX3,8Q@D@`$/D[0```.WMA
ML$@``$!(`!`Y@`,``"^``!%`G@!$2``.Z3M:``%_9-MX?&<;>'_%\WA_X_MX
M?Z;K>'](TWA_*<MX3,8Q@D@`$+%_X_MX.(`!P$@`#\4O@___09[_M'_#\WA(
M``UU?X/C>'_D^WA,QC&"2__MA7_C^WA+__E]2__]F$O_^75_X_MX2``/G7Q_
M&WA+__V$@&$`/"^#``!!G@!@.^```4@``"PZ0```5^D0.F)2@1`[_P`!?E(*
M%'TR2A0]*?__@&E_+"^#``!!G@`P3,8Q@DO_Z-E\:1MY0:+_S(@)```O@```
M09[_P$@`#SE\>!MY08+_M$O_^V`_`!``.QAA($O_^Y"#&0``2__^/#B@__\X
MP/_N..```D@`#=E_(\MX.($`2#B@``9(``QYB`$`2"^```!`G@`0B`$`22^`
M`$-!G@4,.,```'\CRW@XH```..```$@`#9T](&=%.0```&$I(P&1`0`(/,$`
M`9$A``P](._-.0```&$IJXDY0```.6```#@```#(`0`(.D```-@&@$B1`0`(
M.0```)$A``P]()BZ82G<_L@!``C8!H!0D0$`"#D```"1(0`,/2`0,F$I5';(
M`0`(V`:`6)$!``@Y````D2$`##T@P])A*>'PR`$`"-@&@&"1`0`(D2$`#,@!
M``C8!H!HD4$`")%A``S(`0`(D`:`P-@&@'#8!H!X.*```'\CRW@X@0!(8*6`
M`$@`"X%\>!MY0($!G#SA``%7"!@X@2>`<'\`_G"`YX!T*XD``'T(.A1!G0`@
M+XD``#TA``&!28!X@6F`?$">`"!_AT!`0)T`&#XA``&!48!X@7&`?#%K``%]
M2@&45`D8.%<;'WX^80`!5!H??GT[VWB`<X#`.````'UKV!1]2M$4DE.`<&``
M@("1$X!T+X,``)%!``@ZH0!(?N$"%)%A``S(`0`(V!.`>$&>`&@@`P!`?Q7#
M>'^8``!`G0`(?!4#>#C````X@0!(8,:`@'ZEJWA^X3(4?'<:%$@`"ND\X0`!
M@`>`P'P5`A0O@`!`D`>`P$">_P`X8```.0$`2&!C@$A_%<!0?&,*%'ZHJA1+
M_\MQ+Y@`/T"=`%PZ>/_`.M4`0%9TT;Y^N*MX5H`P,G[6`A1_!,-X.*``0'[C
MNW@[&`!`2``*@3A@``!@8X!(?&,*%$O_RRU_F+``0)[_V#@4``%6F#`R5``P
M,G\8F%!^M0(4?P7#>'ZDJWA^X[MX2``*13TA``$XH```DPF`P'\CRW@X@0!(
M8*6``$@`">E\>!MY08'^;'\CRWA(``VY/4$``3E@``"#:H!T86N!$'UK"A2#
M2H!\5V7NOC@%``%]*RH4+X``.#@`_X"8"?]P09T"!#I@```X@```8G.`2'YS
M"A1\<RH4(*4`-SAC`#E(``OE/N$``5='1CY72(0^5TK"/ICW@+A7:T8^5VF$
M/ID7@+E78,(^F5>`NCA@``";5X"[8&.`2#XA``&9=X"\?&,*%)DW@+V8%X"^
MFW>`OTO_RC$\P0`!@2:`9($&@$R!1H!453I&/E4[A#Z!9H!<505&/E42A#Z`
M!H!L51/"/E541CY5580^55;"/IM1@015=T8^57B$/IMQ@055><(^52/"/IBQ
M@/A4!$8^5`:$/II1@/E4!\(^/T`0`)IQ@/J9$8#[.V```#M:89B:D8#\FK&`
M_9K1@/Z948#_FO&!`)L1@0&;,8$"F7&!`YAQ@0:9,8$'F)&!")C1@0F8\8$*
MF!&!"T@``!0Z8```8G.`^'TAFA1\J=BN.D```%=C"#QB4H#,?T33>'Y2"A1\
M<AH43,8Q@D@`"Z$OFP`3.WL``4">_\@X````/N$``9@7@/0XX```/(`0`&#G
M@,P]`!``?\7S>'^FZWA\YPH4.0ABO#B$88A_X_MX3,8Q@D@`"UE_P_-X2``(
M,7^#XWA_Y/MX3,8Q@DO_Z$%_X_MX2__T.4O_^%2#.0`$+YD``$&^^<1_(\MX
M2``)P2N#``-`O?FT.&/__#R`$`!\>1H4.(1A@$@`!Z4O@P``0+[YF'\XRWA+
M__F0.B```#B```!B,8!(.D```'XQ"A1B4H"`?'$J%""E`#\X8P`Y2``)W3A@
M``!@8X!(?&,*%$O_R&E\89(4.(```#B@`#A(``F]2__]V(@!`$HO@`!!0)[Z
M\(@!`$LO@`!#0)[ZY(@!`$PO@`!(0)[ZV(@!`$TO@`!%0)[ZS#C`_\8XX``"
M.*#__W\CRWA(``AE.($`2'\CRW@XH``I2``'!3R`$``]`!``?^/[>#B$88A_
MQ?-X?Z;K>#CA`$@Y"&*\3,8Q@D@`"BU+__F02``'=90A_]!\"`*FDR$`%#\@
M$`*`><X`D`$`-),!`!"300`8DV$`').!`""3H0`DD\$`*)/A`"Q(``I=.```
M`9@#!-4\8!``.&-@8$S&,8)+_^*-+`,``$&"`!"(`P``+X``,4&>`CA+_^_9
M@'G.`#^@$`([O<XD2``*'3R`$``XH``!.(1B&#C```M(``?I+`,``$&"`,R!
M/1`$.\```(%C`!`OB0`!@TL`&$"=`*@_8!`".^```3M[S@!(```L@(D`$'^#
MXWA(``7]@3T0!"^#``!`G@"`._\``3O>``%_B?@`0)T`<(![``!(``FI?T33
M>'_%\W@XP```2``)"7QX&WE!@@'X@3@``%?@$#J!?1`(@4D`"'^+`"YQ2`0`
M0(+_H(![``!(``EM@)@``#B@```XP``"2``&K7QD&WA_@^-X2``%@8$]$`0O
M@P``09[_B#@)__]_@/``09X!4(!YS@`_X!`"2``)+3R`$``XH``!.(1B(#C`
M``1(``;Y?'X;>4&"`#2`?\X`2``)"8$^`!`\H!``.*5B)(")``!(``8U@3X`
M$($I``"`"0`(=`D`0$""`3"`><X`/\`0`D@`"-4\@!``.*```3B$8BPXP``$
M2``&H7Q_&WE!@@`T/&`0`#AC8!A,QC&"2__@\7Q\&WF`?LX`08(!B$@`")F!
M/P`0?X7C>(")``!(``7)@'G.`$@`"($X````F`,$U8!YS@!(``AQ.````)`#
M!DP\8!``.&-@#$S&,8)+_^"A+X,``)!]$`Q!G@#(.(`!P$@`!O5\9AMY08(`
M%"^&`!%!G@`,+X;__T">`8R``0`T@P$`$'P(`Z:#(0`4@T$`&(-A`!R#@0`@
M@Z$`)(/!`"B#X0`L."$`,$Z``""(`P`!+X```$&^_<A+__W`+XD``4"]_K`_
M8!`".^```3M[S@"`>P``._\``4@`!\U_1--X2``$58`=$`1_@/@`09W_Y$O_
M_H"`?\X`2``'K8$^`!"`B0``2``&P4O__L"!/1`$.`G__W^`\`!`GOY82___
MH(!]$`A+__%Q+X,``)!]$`Q!G@#$@3\`$($I``"`"0`(<`L$`$&"`&B`:0`0
M@)T0"$@`!'6!/P`0@7T0"'Q^&WB!*0``@ZL``(`)``AP"`0`08(`8("I`!`\
M8!``?Z3K>#AC8E1_QO-X3,8Q@D@`!9E(``<5@7\`$($]$`B`:P``@(D``$O_
MY?%+__YX/2`0`H!IS@!(``;Q@3\`$#B@```XP``"@(D``$@`!"U+__^`@'G.
M`$@`!M&!/P`0.*```#C```*`B0``2``$#7QE&WA+__^(/&`0`#AC8C!,QC&"
M2``%)8$]$`@\8!``@+T0##AC8GR`B0``3,8Q@D@`!0F4(?_@?`@"II/!`!A\
M?AMXD`$`))/A`!Q+_^I9B`,``'Q_&W@O@```09X`/#DC``%\:QMX2```%(P+
M``$Y*0`!+X```$&>`"`O@``O0)[_[(P+``%]/TMX.2D``2^```!`GO_H2__M
M_2^#``!!G@`P+YX``$&>`"B('@``+X```$&>`!P\@!``?^/[>#B$831(``(5
M?Y\8`$&>`!R``0`D@\$`&'P(`Z:#X0`<."$`($Z``""``0`D?\/S>(/A`!Q\
M"`.F@\$`&#@A`"!+_^`(E"'_X'P(`J:3X0`</^`0`H!_S@"0`0`D2``%G3B`
M__](``,%@'_.`$@`!8T\@!``.*```#B$-BA(``5-@`$`)(/A`!PX(0`@?`@#
MIDZ``"``````?`@"ID*?``64(?_P.,```)/!``B0`0`4?\@"IC_>``([WIA,
M@3Z``"^)``!!G@`(@,D``$@``JV``0`4@\$`"#@A`!!\"`.F3H``(`````!.
M@``@8````&````!@````E"'_T'P(`J9"GP`%D\$`*).A`"23(0`4DT$`&'RY
M*WA\FB-XDV$`').!`"!\>QMXD`$`-)/A`"Q_R`*F/]X``CO>E^Q+_[XA@[Z`
M!(.>@`!_G>!0?YP6<4&"`#`[X```5^`0.G]CVWA_1--X?R7+>#O_``%\'0`N
M?`D#IDZ`!"%_G^!`09S_W(`!`#2#(0`4@T$`&(-A`!Q\"`.F@X$`((.A`"2#
MP0`H@^$`+#@A`#!.@``@E"'_\'P(`J:0`0`4D^$`##_@$`$[_W`$@!___"^`
M__]!G@`<.____'P)`Z9.@`0AA!___"^`__]`GO_P@`$`%(/A``PX(0`0?`@#
MIDZ``""4(?_P?`@"II`!`!2``0`4."$`$'P(`Z9.@``@/6`0`8%K<3A]:0.F
M3H`$(#U@$`&!:W$\?6D#IDZ`!"`]8!`!@6MQ0'UI`Z9.@`0@/6`0`8%K<41]
M:0.F3H`$(#U@$`&!:W%(?6D#IDZ`!"`]8!`!@6MQ3'UI`Z9.@`0@/6`0`8%K
M<5!]:0.F3H`$(#U@$`&!:W%4?6D#IDZ`!"`]8!`!@6MQ6'UI`Z9.@`0@/6`0
M`8%K<5Q]:0.F3H`$(#U@$`&!:W%@?6D#IDZ`!"`]8!`!@6MQ9'UI`Z9.@`0@
M/6`0`8%K<6A]:0.F3H`$(#U@$`&!:W%L?6D#IDZ`!"`]8!`!@6MQ<'UI`Z9.
M@`0@/6`0`8%K<71]:0.F3H`$(#U@$`&!:W%X?6D#IDZ`!"`]8!`!@6MQ?'UI
M`Z9.@`0@/6`0`8%K<8!]:0.F3H`$(#U@$`&!:W&$?6D#IDZ`!"`]8!`!@6MQ
MB'UI`Z9.@`0@/6`0`8%K<8Q]:0.F3H`$(#U@$`&!:W&0?6D#IDZ`!"`]8!`!
M@6MQE'UI`Z9.@`0@/6`0`8%K<9A]:0.F3H`$(#U@$`&!:W&<?6D#IDZ`!"`]
M8!`!@6MQH'UI`Z9.@`0@/6`0`8%K<:1]:0.F3H`$(#U@$`&!:W&H?6D#IDZ`
M!"`]8!`!@6MQK'UI`Z9.@`0@/6`0`8%K<;!]:0.F3H`$(#U@$`&!:W&T?6D#
MIDZ`!"`]8!`!@6MQN'UI`Z9.@`0@/6`0`8%K<;Q]:0.F3H`$(#U@$`&!:W'`
M?6D#IDZ`!"`]8!`!@6MQQ'UI`Z9.@`0@/6`0`8%K<<A]:0.F3H`$(#U@$`&!
M:W',?6D#IDZ`!"`]8!`!@6MQT'UI`Z9.@`0@/6`0`8%K<=1]:0.F3H`$(#U@
M$`&!:W'8?6D#IDZ`!"`]8!`!@6MQW'UI`Z9.@`0@/6`0`8%K<>!]:0.F3H`$
M(#U@$`&!:W'D?6D#IDZ`!"`]8!`!@6MQZ'UI`Z9.@`0@/6`0`8%K<>Q]:0.F
M3H`$(#U@$`&!:W'P?6D#IDZ`!"`]8!`!@6MQ]'UI`Z9.@`0@/6`0`8%K<?A]
M:0.F3H`$(#U@$`&!:W'\?6D#IDZ`!"`]8!`!@6MR`'UI`Z9.@`0@/6`0`8%K
M<@1]:0.F3H`$(#U@$`&!:W((?6D#IDZ`!"`]8!`!@6MR#'UI`Z9.@`0@/6`0
M`8%K<A!]:0.F3H`$(#U@$`&!:W(4?6D#IDZ`!"`]8!`!@6MR&'UI`Z9.@`0@
M/6`0`8%K<AQ]:0.F3H`$(#U@$`&!:W(@?6D#IDZ`!"`]8!`!@6MR)'UI`Z9.
M@`0@/6`0`8%K<BA]:0.F3H`$(#U@$`&!:W(L?6D#IDZ`!"`]8!`!@6MR,'UI
M`Z9.@`0@/6`0`8%K<C1]:0.F3H`$(#U@$`&!:W(X?6D#IDZ`!"`]8!`!@6MR
M/'UI`Z9.@`0@/6`0`8%K<D!]:0.F3H`$(#U@$`&!:W)$?6D#IDZ`!"!(``$0
M2``!#$@``0A(``$$2``!`$@``/Q(``#X2```]$@``/!(``#L2```Z$@``.1(
M``#@2```W$@``-A(``#42```T$@``,Q(``#(2```Q$@``,!(``"\2```N$@`
M`+1(``"P2```K$@``*A(``"D2```H$@``)Q(``"82```E$@``)!(``",2```
MB$@``(1(``"`2```?$@``'A(``!T2```<$@``&Q(``!H2```9$@``&!(``!<
M2```6$@``%1(``!02```3$@``$A(``!$2```0$@``#Q(```X2```-$@``#!(
M```L2```*$@``"1@````8````&````!@````8````&````!@````8````#V`
M$`$]:_``@`QQ,#EKHH!\"0.F?`M:%(&,<31]8%H43H`$(&````!@````8```
M`&````!@````8````&````"4(?_P?`@"II`!`!23P0`(0I\`!7_(`J8_W@`!
M.]X22$O_ND6``0`4?`@#IH/!``@X(0`03H``(!`"3?D0`!;0$`!8(!``6!``
M`@`!7U]%3E9?4$%27T-,14%.7U\@("`@("`@("`@("`@("``````$`!BR!``
M8M@0`&+@$`!BZ!``8O`0`&,$`````!``8Q`0`&`(`````!``8.`0`&#D$`!C
M&!``8!`0`&,@`````!``8R00`&,L`````%F``````````````$'/____@```
M)7,O)7,````O<')O8R]S96QF+V5X90``1'EN84QO861E<CHZ8F]O=%]$>6YA
M3&]A9&5R`'!E<FQX<VDN8P```$EN=&5R;F%L<SHZ4$%2.CI"3T]4`````"]P
M<F]C+R5I+R5S`&5X90`N````4$%27U1%35``````4$%27U!23T=.04U%````
M`#H````E<R5S)7,``"\```!015),-4Q)0@````!015),3$E"`%!%4DPU3U!4
M`````%!%4DQ)3P``4$%27TE.251)04Q)6D5$`%!!4E]34$%73D5$`%!!4E]#
M3$5!3@```%!!4E]$14)51P```%!!4E]#04-(10```%!!4E]!4D=#`````%!!
M4E]!4D=67S```%!!4E]'3$]"04Q?1$5"54<`````4$%27T=,3T)!3%]435!$
M25(```!005)?5$U01$E2``!005)?1TQ/0D%,7U1%35``4$%27T=,3T)!3%]#
M3$5!3@````!005)?0TQ%04X]```Q````4UE35$5-```E<R5S)7,E<P````!P
M87(M`````"5S.B!C<F5A=&EO;B!O9B!P<FEV871E('-U8F1I<F5C=&]R>2`E
M<R!F86EL960@*&5R<FYO/25I*0H``'!A<FP`````+G!A<@`````E<R5S8V%C
M:&4M)7,E<P``)3`R>``````E<R5S=&5M<"TE=25S````)7,E<W1E;7`M)74M
M)74E<P`````E<SH@<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@:7,@=6YS869E
M("AP;&5A<V4@<F5M;W9E(&ET(&%N9"!R971R>2!Y;W5R(&]P97)A=&EO;BD*
M``!!4D=6`````!@```!P97)L`````#````!5;F%B;&4@=&\@8W)E871E(&-A
M8VAE(&1I<F5C=&]R>0`````E<SH@97AE8W5T:6]N(&]F("5S(&9A:6QE9"`H
M97)R;F\])6DI"@``)7,Z(&-R96%T:6]N(&]F('!R:79A=&4@8V%C:&4@<W5B
M9&ER96-T;W)Y("5S(&9A:6QE9"`H97)R;F\])6DI"@`````M90``+2T``$Q$
M7TQ)0E)!4EE?4$%42`!,24)0051(`$Q)0E)!4EE?4$%42`````!$64Q$7TQ)
M0E)!4EE?4$%42````%-(3$E"7U!!5$@``"]T;7``````5$5-4$1)4@!435``
M55-%4@````!54T523D%-10`````!&P,[````$`````'__[78````*````!``
M`````7I2``1\00$;#`$`````$````!C__[6H````)``````````0``````%Z
M4@`$?$$!&PP!`````!`````8___UL```!9``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````/____\`````_____P``````````$`%R4!`!<``0`7```````0``
M``$````!```!SP````$```':`````0```>0````!```",P````$```-^````
M#!``%H0````-$`!>T`````00``&(;__^]1``!+0````%$``,,`````80``6P
M````"@``!/@````+````$````!4``````````Q`!<3@````"```#,````!0`
M```'````%Q``$U1P````$`%Q+`````<0`!*(````"````_P````)````#```
M`!8`````;____A``$?AO____`````F____`0`!$H````````````````````
M`````````````````````````````````````````````````!`!<"``````
M`````!``78`0`%V$$`!=B!``78P0`%V0$`!=E!``79@0`%V<$`!=H!``7:00
M`%VH$`!=K!``7;`0`%VT$`!=N!``7;P0`%W`$`!=Q!``7<@0`%W,$`!=T!``
M7=00`%W8$`!=W!``7>`0`%WD$`!=Z!``7>P0`%WP$`!=]!``7?@0`%W\$`!>
M`!``7@00`%X($`!>#!``7A`0`%X4$`!>&!``7AP0`%X@$`!>)!``7B@0`%XL
M$`!>,!``7C00`%XX$`!>/!``7D`0`%Y$$`!>2!``7DP0`%Y0$`!>5!``7E@0
M`%Y<$`!>8!``7F00`%YH$`!>;!``7G`0`%YT$`!>>!``7GP0`%Z`$`!>A!``
M7H@0`%Z,````````````````_____R,A+W5S<B]B:6XO<&5R;`IE=F%L("=E
M>&5C("]U<W(O8FEN+W!E<FP@("U3("0P("1[,2LB)$`B?2<*("`@(&EF(#`[
M(",@;F]T(')U;FYI;F<@=6YD97(@<V]M92!S:&5L;`H*<&%C:V%G92!?7W!A
M<E]P;#L*"B,@+2TM(%1H:7,@<V-R:7!T(&UU<W0@;F]T('5S92!A;GD@;6]D
M=6QE<R!A="!C;VUP:6QE('1I;64@+2TM"B,@=7-E('-T<FEC=#L*"B-L:6YE
M(#$U.`H*;7D@*"1P87)?=&5M<"P@)'!R;V=N86UE+"!`=&UP9FEL92D["D5.
M1"![(&EF("@D14Y6>U!!4E]#3$5!3GTI('L*("`@(')E<75I<F4@1FEL93HZ
M5&5M<#L*("`@(')E<75I<F4@1FEL93HZ0F%S96YA;64["B`@("!R97%U:7)E
M($9I;&4Z.E-P96,["B`@("!M>2`D=&]P9&ER(#T@1FEL93HZ0F%S96YA;64Z
M.F1I<FYA;64H)'!A<E]T96UP*3L*("`@(&]U=',H<7%[4F5M;W9I;F<@9FEL
M97,@:6X@(B1P87)?=&5M<")]*3L*("`@($9I;&4Z.D9I;F0Z.F9I;F1D97!T
M:"AS=6(@>R`H("UD("D@/R!R;61I<B`Z('5N;&EN:R!]+"`D<&%R7W1E;7`I
M.PH@("`@<FUD:7(@)'!A<E]T96UP.PH@("`@(R!$;VXG="!R96UO=F4@=&]P
M9&ER(&)E8V%U<V4@=&AI<R!C875S97,@82!R86-E('=I=&@@;W1H97(@87!P
M<PH@("`@(R!T:&%T(&%R92!T<GEI;F<@=&\@<W1A<G0N"@H@("`@:68@*"UD
M("1P87)?=&5M<"`F)B`D7D\@;F4@)TU35VEN,S(G*2!["B`@("`@("`@(R!3
M;VUE=&AI;F<@=V5N="!W<F]N9R!U;FQI;FMI;F<@=&AE('1E;7!O<F%R>2!D
M:7)E8W1O<GDN("!4:&ES"B`@("`@("`@(R!T>7!I8V%L;'D@:&%P<&5N<R!O
M;B!P;&%T9F]R;7,@=&AA="!D:7-A;&QO=R!U;FQI;FMI;F<@<VAA<F5D"B`@
M("`@("`@(R!L:6)R87)I97,@86YD(&5X96-U=&%B;&5S('1H870@87)E(&EN
M('5S92X@56YL:6YK('=I=&@@82!B86-K9W)O=6YD"B`@("`@("`@(R!S:&5L
M;"!C;VUM86YD('-O('1H92!F:6QE<R!A<F4@;F\@;&]N9V5R(&EN('5S92!B
M>2!T:&ES('!R;V-E<W,N"B`@("`@("`@(R!$;VXG="!D;R!A;GET:&EN9R!O
M;B!7:6YD;W=S(&)E8V%U<V4@;W5R('!A<F5N="!P<F]C97-S('=I;&P*("`@
M("`@("`C('1A:V4@8V%R92!O9B!C;&5A;FEN9R!T:&EN9W,@=7`N"@H@("`@
M("`@(&UY("1T;7`@/2!N97<@1FEL93HZ5&5M<"@*("`@("`@("`@("`@5$5-
M4$Q!5$4@/3X@)W1M<%A86%A8)RP*("`@("`@("`@("`@1$E2(#T^($9I;&4Z
M.D)A<V5N86UE.CID:7)N86UE*"1T;W!D:7(I+`H@("`@("`@("`@("!3549&
M25@@/3X@)RYC;60G+`H@("`@("`@("`@("!53DQ)3DL@/3X@,"P*("`@("`@
M("`I.PH*("`@("`@("!P<FEN="`D=&UP("(C(2]B:6XO<V@*>#TQ.R!W:&EL
M92!;(%PD>"`M;'0@,3`@73L@9&\*("`@<FT@+7)F("<D<&%R7W1E;7`G"B`@
M(&EF(%L@7"$@+60@)R1P87)?=&5M<"<@73L@=&AE;@H@("`@("`@8G)E86L*
M("`@9FD*("`@<VQE97`@,0H@("!X/6!E>'!R(%PD>"`K(#%@"F1O;F4*<FT@
M)R(@+B`D=&UP+3YF:6QE;F%M92`N("(G"B(["B`@("`@("`@("`@(&-H;6]D
M(#`W,#`L)'1M<"T^9FEL96YA;64["B`@("`@("`@;7D@)&-M9"`]("1T;7`M
M/F9I;&5N86UE("X@)R`^+V1E=B]N=6QL(#(^)C$@)B<["B`@("`@("`@8VQO
M<V4@)'1M<#L*("`@("`@("!S>7-T96TH)&-M9"D["B`@("`@("`@;W5T<RAQ
M<2A3<&%W;F5D(&)A8VMG<F]U;F0@<')O8V5S<R!T;R!P97)F;W)M(&-L96%N
M=7`Z("D*("`@("`@("`@("`@("X@)'1M<"T^9FEL96YA;64I.PH@("`@?0I]
M('T*"D)%1TE.('L*("`@($EN=&5R;F%L<SHZ4$%2.CI"3T]4*"D@:68@9&5F
M:6YE9"`F26YT97)N86QS.CI005(Z.D)/3U0["@H@("`@979A;"!["@I?<&%R
M7VEN:71?96YV*"D["@II9B`H97AI<W1S("1%3E9[4$%27T%21U9?,'T@86YD
M("1%3E9[4$%27T%21U9?,'T@*2!["B`@("!`05)'5B`](&UA<"`D14Y6>R)0
M05)?05)'5E\D7R)]+"`H,2`N+B`D14Y6>U!!4E]!4D=#?2`M(#$I.PH@("`@
M)#`@/2`D14Y6>U!!4E]!4D=67S!].PI]"F5L<V4@>PH@("`@9F]R("AK97ES
M("5%3E8I('L*("`@("`@("!D96QE=&4@)$5.5GLD7WT@:68@+UY005)?05)'
M5E\O.PH@("`@?0I]"@IM>2`D<75I970@/2`A)$5.5GM005)?1$5"54=].PH*
M(R!F:7@@)'!R;V=N86UE(&EF(&EN=F]K960@9G)O;2!0051("FUY("5#;VYF
M:6<@/2`H"B`@("!P871H7W-E<"`@("`]/B`H)%Y/(#U^("]>35-7:6XO(#\@
M)SLG(#H@)SHG*2P*("`@(%]E>&4@("`@("`@(#T^("@D7D\@/7X@+UXH/SI-
M4U=I;GQ/4S)\8WEG=VEN*2\@/R`G+F5X92<@.B`G)RDL"B`@("!?9&5L:6T@
M("`@("`]/B`H)%Y/(#U^("]>35-7:6Y\3U,R+R`_("=<7"<@.B`G+R<I+`HI
M.PH*7W-E=%]P<F]G;F%M92@I.PI?<V5T7W!A<E]T96UP*"D["@HC($UA9VEC
M('-T<FEN9R!C:&5C:VEN9R!A;F0@97AT<F%C=&EN9R!B=6YD;&5D(&UO9'5L
M97,@>WM["FUY("@D<W1A<G1?<&]S+"`D9&%T85]P;W,I.PI["B`@("!L;V-A
M;"`D4TE'>U]?5T%23E]??2`]('-U8B![?3L*"B`@("`C($-H96-K(&9I;&4@
M='EP92P@9V5T('-T87)T(&]F(&1A=&$@<V5C=&EO;B![>WL*("`@(&]P96X@
M7T9(+"`G/"<L("1P<F]G;F%M92!O<B!L87-T.PH@("`@8FEN;6]D92A?1D@I
M.PH*("`@(&UY("1B=68["B`@("!S965K(%]&2"P@+3@L(#(["B`@("!R96%D
M(%]&2"P@)&)U9BP@.#L*("`@(&QA<W0@=6YL97-S("1B=68@97$@(EQN4$%2
M+G!M7&XB.PH*("`@('-E96L@7T9(+"`M,3(L(#(["B`@("!R96%D(%]&2"P@
M)&)U9BP@-#L*("`@('-E96L@7T9(+"`M,3(@+2!U;G!A8VLH(DXB+"`D8G5F
M*2P@,CL*("`@(')E860@7T9(+"`D8G5F+"`T.PH*("`@("1D871A7W!O<R`]
M("AT96QL(%]&2"D@+2`T.PH@("`@(R!]?7T*"B`@("`C($5X=')A8W1I;F<@
M96%C:"!F:6QE(&EN=&\@;65M;W)Y('M[>PH@("`@;7D@)7)E<75I<F5?;&ES
M=#L*("`@('=H:6QE("@D8G5F(&5Q(")&24Q%(BD@>PH@("`@("`@(')E860@
M7T9(+"`D8G5F+"`T.PH@("`@("`@(')E860@7T9(+"`D8G5F+"!U;G!A8VLH
M(DXB+"`D8G5F*3L*"B`@("`@("`@;7D@)&9U;&QN86UE(#T@)&)U9CL*("`@
M("`@("!O=71S*'%Q*%5N<&%C:VEN9R!F:6QE("(D9G5L;&YA;64B+BXN*2D[
M"B`@("`@("`@;7D@)&-R8R`]("@@)&9U;&QN86UE(#U^('-\7BA;82UF7&1=
M>SA]*2]\?"`I(#\@)#$@.B!U;F1E9CL*("`@("`@("!M>2`H)&)A<V5N86UE
M+"`D97AT*2`]("@D8G5F(#U^(&U\*#\Z+BHO*3\H+BHI*%PN+BHI?"D["@H@
M("`@("`@(')E860@7T9(+"`D8G5F+"`T.PH@("`@("`@(')E860@7T9(+"`D
M8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*"B`@("`@("`@:68@*&1E9FEN960H
M)&5X="D@86YD("1E>'0@(7X@+UPN*#\Z<&U\<&Q\:7A\86PI)"]I*2!["B`@
M("`@("`@("`@(&UY("@D;W5T+"`D9FEL96YA;64I(#T@7W1E;7!F:6QE*"1E
M>'0L("1C<F,I.PH@("`@("`@("`@("!I9B`H)&]U="D@>PH@("`@("`@("`@
M("`@("`@8FEN;6]D92@D;W5T*3L*("`@("`@("`@("`@("`@('!R:6YT("1O
M=70@)&)U9CL*("`@("`@("`@("`@("`@(&-L;W-E("1O=70["B`@("`@("`@
M("`@("`@("!C:&UO9"`P-S4U+"`D9FEL96YA;64["B`@("`@("`@("`@('T*
M("`@("`@("`@("`@)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9G5L;&YA;65]
M(#T@)&9I;&5N86UE.PH@("`@("`@("`@("`D4$%2.CI(96%V>3HZ1G5L;$-A
M8VAE>R1F:6QE;F%M97T@/2`D9G5L;&YA;64["B`@("`@("`@?0H@("`@("`@
M(&5L<VEF("@@)&9U;&QN86UE(#U^(&U\7B\_<VAL:6(O?"!A;F0@9&5F:6YE
M9"`D14Y6>U!!4E]414U0?2`I('L*("`@("`@("`@("`@(R!S:&]U;&0@8F4@
M;6]V960@=&\@7W1E;7!F:6QE*"D*("`@("`@("`@("`@;7D@)&9I;&5N86UE
M(#T@(B1%3E9[4$%27U1%35!]+R1B87-E;F%M921E>'0B.PH@("`@("`@("`@
M("!O=71S*")32$Q)0CH@)&9I;&5N86UE7&XB*3L*("`@("`@("`@("`@;W!E
M;B!M>2`D;W5T+"`G/B<L("1F:6QE;F%M92!O<B!D:64@)"$["B`@("`@("`@
M("`@(&)I;FUO9&4H)&]U="D["B`@("`@("`@("`@('!R:6YT("1O=70@)&)U
M9CL*("`@("`@("`@("`@8VQO<V4@)&]U=#L*("`@("`@("!]"B`@("`@("`@
M96QS92!["B`@("`@("`@("`@("1R97%U:7)E7VQI<W1[)&9U;&QN86UE?2`]
M"B`@("`@("`@("`@("1005(Z.DAE879Y.CI-;V1U;&5#86-H97LD9G5L;&YA
M;65](#T@>PH@("`@("`@("`@("`@("`@8G5F(#T^("1B=68L"B`@("`@("`@
M("`@("`@("!C<F,@/3X@)&-R8RP*("`@("`@("`@("`@("`@(&YA;64@/3X@
M)&9U;&QN86UE+`H@("`@("`@("`@("!].PH@("`@("`@('T*("`@("`@("!R
M96%D(%]&2"P@)&)U9BP@-#L*("`@('T*("`@(",@?7U]"@H@("`@;&]C86P@
M0$E.0R`]("AS=6(@>PH@("`@("`@(&UY("@D<V5L9BP@)&UO9'5L92D@/2!`
M7SL*"B`@("`@("`@<F5T=7)N(&EF(')E9B`D;6]D=6QE(&]R("$D;6]D=6QE
M.PH*("`@("`@("!M>2`D9FEL96YA;64@/2!D96QE=&4@)')E<75I<F5?;&ES
M='LD;6]D=6QE?2!\?"!D;R!["B`@("`@("`@("`@(&UY("1K97D["B`@("`@
M("`@("`@(&9O<F5A8V@@*&ME>7,@)7)E<75I<F5?;&ES="D@>PH@("`@("`@
M("`@("`@("`@;F5X="!U;FQE<W,@+UQ1)&UO9'5L95Q%)"\["B`@("`@("`@
M("`@("`@("`D:V5Y(#T@)%\[(&QA<W0["B`@("`@("`@("`@('T*("`@("`@
M("`@("`@9&5L971E("1R97%U:7)E7VQI<W1[)&ME>7T@:68@9&5F:6YE9"@D
M:V5Y*3L*("`@("`@("!](&]R(')E='5R;CL*"B`@("`@("`@)$E.0WLD;6]D
M=6QE?2`]("(O;&]A9&5R+R1F:6QE;F%M92\D;6]D=6QE(CL*"B`@("`@("`@
M:68@*"1%3E9[4$%27T-,14%.?2!A;F0@9&5F:6YE9"@F24\Z.D9I;&4Z.FYE
M=RDI('L*("`@("`@("`@("`@;7D@)&9H(#T@24\Z.D9I;&4M/FYE=U]T;7!F
M:6QE(&]R(&1I92`D(3L*("`@("`@("`@("`@8FEN;6]D92@D9F@I.PH@("`@
M("`@("`@("!P<FEN="`D9F@@)&9I;&5N86UE+3Y[8G5F?3L*("`@("`@("`@
M("`@<V5E:R@D9F@L(#`L(#`I.PH@("`@("`@("`@("!R971U<FX@)&9H.PH@
M("`@("`@('T*("`@("`@("!E;'-E('L*("`@("`@("`@("`@;7D@*"1O=70L
M("1N86UE*2`](%]T96UP9FEL92@G+G!M)RP@)&9I;&5N86UE+3Y[8W)C?2D[
M"B`@("`@("`@("`@(&EF("@D;W5T*2!["B`@("`@("`@("`@("`@("!B:6YM
M;V1E*"1O=70I.PH@("`@("`@("`@("`@("`@<')I;G0@)&]U="`D9FEL96YA
M;64M/GMB=69].PH@("`@("`@("`@("`@("`@8VQO<V4@)&]U=#L*("`@("`@
M("`@("`@?0H@("`@("`@("`@("!O<&5N(&UY("1F:"P@)SPG+"`D;F%M92!O
M<B!D:64@)"$["B`@("`@("`@("`@(&)I;FUO9&4H)&9H*3L*("`@("`@("`@
M("`@<F5T=7)N("1F:#L*("`@("`@("!]"@H@("`@("`@(&1I92`B0F]O='-T
M<F%P<&EN9R!F86EL960Z(&-A;FYO="!F:6YD("1M;V1U;&4A7&XB.PH@("`@
M?2P@0$E.0RD["@H@("`@(R!.;W<@;&]A9"!A;&P@8G5N9&QE9"!F:6QE<R![
M>WL*"B`@("`C(&EN:71I86QI>F4@<VAA<F5D(&]B:F5C="!P<F]C97-S:6YG
M"B`@("!R97%U:7)E(%A33&]A9&5R.PH@("`@<F5Q=6ER92!005(Z.DAE879Y
M.PH@("`@<F5Q=6ER92!#87)P.CI(96%V>3L*("`@(')E<75I<F4@17AP;W)T
M97(Z.DAE879Y.PH@("`@4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I
M.PH*("`@(",@;F]W(&QE="=S('1R>2!G971T:6YG(&AE;'!E<B!M;V1U;&5S
M(&9R;VT@=VET:&EN"B`@("!R97%U:7)E($E/.CI&:6QE.PH*("`@(",@;&]A
M9"!R97-T(&]F('1H92!G<F]U<"!I;@H@("`@=VAI;&4@*&UY("1F:6QE;F%M
M92`]("AS;W)T(&ME>7,@)7)E<75I<F5?;&ES="E;,%TI('L*("`@("`@("`C
M;&]C86P@)$E.0WLG0W=D+G!M)WT@/2!?7T9)3$5?7R!I9B`D7D\@;F4@)TU3
M5VEN,S(G.PH@("`@("`@('5N;&5S<R`H)$E.0WLD9FEL96YA;65](&]R("1F
M:6QE;F%M92`]?B`O0E-$4$%.+RD@>PH@("`@("`@("`@("`C(')E<75I<F4@
M;6]D=6QE<RP@9&\@;W1H97(@97AE8W5T86)L92!F:6QE<PH@("`@("`@("`@
M("!I9B`H)&9I;&5N86UE(#U^("]<+G!M8S\D+VDI('L*("`@("`@("`@("`@
M("`@(')E<75I<F4@)&9I;&5N86UE.PH@("`@("`@("`@("!]"B`@("`@("`@
M("`@(&5L<V4@>PH@("`@("`@("`@("`@("`@(R!3:VEP($%C=&EV95-T871E
M)W,@<VET96-U<W1O;6EZ92YP;"!F:6QE.@H@("`@("`@("`@("`@("`@9&\@
M)&9I;&5N86UE('5N;&5S<R`D9FEL96YA;64@/7X@+W-I=&5C=7-T;VUI>F5<
M+G!L)"\["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@9&5L971E
M("1R97%U:7)E7VQI<W1[)&9I;&5N86UE?3L*("`@('T*"B`@("`C('U]?0H*
M("`@(&QA<W0@=6YL97-S("1B=68@97$@(E!+7#`P,UPP,#0B.PH@("`@)'-T
M87)T7W!O<R`]("AT96QL(%]&2"D@+2`T.PI]"B,@?7U]"@HC($%R9W5M96YT
M('!R;V-E<W-I;F<@>WM["FUY($!P87)?87)G<SL*;7D@*"1O=70L("1B=6YD
M;&4L("1L;V=F:"P@)&-A8VAE7VYA;64I.PH*9&5L971E("1%3E9[4$%27T%0
M4%]2155317T[(",@<V%N:71I>F4@*%)%55-%(&UA>2!B92!A('-E8W5R:71Y
M('!R;V)L96TI"@HD<75I970@/2`P('5N;&5S<R`D14Y6>U!!4E]$14)51WT[
M"B,@1&]N)W0@<W=A;&QO=R!A<F=U;65N=',@9F]R(&-O;7!I;&5D(&5X96-U
M=&%B;&5S('=I=&AO=70@+2UP87(M;W!T:6]N<PII9B`H(21S=&%R=%]P;W,@
M;W(@*"1!4D=66S!=(&5Q("<M+7!A<BUO<'1I;VYS)R`F)B!S:&EF="DI('L*
M("`@(&UY("5D:7-T7V-M9"`]('%W*`H@("`@("`@('`@("!B;&EB7W1O7W!A
M<@H@("`@("`@(&D@("!I;G-T86QL7W!A<@H@("`@("`@('4@("!U;FEN<W1A
M;&Q?<&%R"B`@("`@("`@<R`@('-I9VY?<&%R"B`@("`@("`@=B`@('9E<FEF
M>5]P87(*("`@("D["@H@("`@(R!I9B!T:&4@87!P(&ES(&EN=F]K960@87,@
M(F%P<&YA;64@+2UP87(M;W!T:6]N<R`M+7)E=7-E(%!23T=204T@0%!23T=?
M05)'5B(L"B`@("`C('5S92!T:&4@87!P('1O(')U;B!T:&4@9VEV96X@<&5R
M;"!C;V1E(&EN<W1E860@;V8@86YY=&AI;F<@9G)O;2!T:&4*("`@(",@87!P
M(&ET<V5L9B`H8G5T('-T:6QL('-E="!U<"!T:&4@;F]R;6%L(&%P<"!E;G9I
M<F]N;65N="!A;F0@0$E.0RD*("`@(&EF("A`05)'5B!A;F0@)$%21U9;,%T@
M97$@)RTM<F5U<V4G*2!["B`@("`@("`@<VAI9G0@0$%21U8["B`@("`@("`@
M)$5.5GM005)?05!07U)%55-%?2`]('-H:69T($!!4D=6.PH@("`@?0H@("`@
M96QS92![(",@;F]R;6%L('!A<FP@8F5H879I;W5R"@H@("`@("`@(&UY($!A
M9&1?=&]?:6YC.PH@("`@("`@('=H:6QE("A`05)'5BD@>PH@("`@("`@("`@
M("`D05)'5ELP72`]?B`O7BTH6T%)34]"3&)Q<&EU<U1V72DH+BHI+R!O<B!L
M87-T.PH*("`@("`@("`@("`@:68@*"0Q(&5Q("=))RD@>PH@("`@("`@("`@
M("`@("`@<'5S:"!`861D7W1O7VEN8RP@)#(["B`@("`@("`@("`@('T*("`@
M("`@("`@("`@96QS:68@*"0Q(&5Q("=-)RD@>PH@("`@("`@("`@("`@("`@
M979A;"`B=7-E("0R(CL*("`@("`@("`@("`@?0H@("`@("`@("`@("!E;'-I
M9B`H)#$@97$@)T$G*2!["B`@("`@("`@("`@("`@("!U;G-H:69T($!P87)?
M87)G<RP@)#(["B`@("`@("`@("`@('T*("`@("`@("`@("`@96QS:68@*"0Q
M(&5Q("=/)RD@>PH@("`@("`@("`@("`@("`@)&]U="`]("0R.PH@("`@("`@
M("`@("!]"B`@("`@("`@("`@(&5L<VEF("@D,2!E<2`G8B<I('L*("`@("`@
M("`@("`@("`@("1B=6YD;&4@/2`G<VET92<["B`@("`@("`@("`@('T*("`@
M("`@("`@("`@96QS:68@*"0Q(&5Q("=")RD@>PH@("`@("`@("`@("`@("`@
M)&)U;F1L92`]("=A;&PG.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&5L
M<VEF("@D,2!E<2`G<2<I('L*("`@("`@("`@("`@("`@("1Q=6EE="`](#$[
M"B`@("`@("`@("`@('T*("`@("`@("`@("`@96QS:68@*"0Q(&5Q("=,)RD@
M>PH@("`@("`@("`@("`@("`@;W!E;B`D;&]G9F@L("(^/B(L("0R(&]R(&1I
M92`B6%A8.B!#86YN;W0@;W!E;B!L;V<Z("0A(CL*("`@("`@("`@("`@?0H@
M("`@("`@("`@("!E;'-I9B`H)#$@97$@)U0G*2!["B`@("`@("`@("`@("`@
M("`D8V%C:&5?;F%M92`]("0R.PH@("`@("`@("`@("!]"@H@("`@("`@("`@
M("!S:&EF="A`05)'5BD["@H@("`@("`@("`@("!I9B`H;7D@)&-M9"`]("1D
M:7-T7V-M9'LD,7TI('L*("`@("`@("`@("`@("`@(&1E;&5T92`D14Y6>R=0
M05)?5$5-4"=].PH@("`@("`@("`@("`@("`@:6YI=%]I;F,H*3L*("`@("`@
M("`@("`@("`@(')E<75I<F4@4$%2.CI$:7-T.PH@("`@("`@("`@("`@("`@
M)GLB4$%2.CI$:7-T.CHD8VUD(GTH*2!U;FQE<W,@0$%21U8["B`@("`@("`@
M("`@("`@("`F>R)005(Z.D1I<W0Z.B1C;60B?2@D7RD@9F]R($!!4D=6.PH@
M("`@("`@("`@("`@("`@97AI=#L*("`@("`@("`@("`@?0H@("`@("`@('T*
M"B`@("`@("`@=6YS:&EF="!`24Y#+"!`861D7W1O7VEN8SL*("`@('T*?0H*
M(R!86%@@+2T@861D("TM<&%R+61E8G5G('-U<'!O<G0A"@HC('U]?0H*(R!/
M=71P=70@;6]D92`H+4\I(&AA;F1L:6YG('M[>PII9B`H)&]U="D@>PH@("`@
M>PH@("`@("`@("-L;V-A;"`D24Y#>R=#=V0N<&TG?2`](%]?1DE,15]?(&EF
M("1>3R!N92`G35-7:6XS,B<["B`@("`@("`@<F5Q=6ER92!)3SHZ1FEL93L*
M("`@("`@("!R97%U:7)E($%R8VAI=F4Z.EII<#L*("`@('T*"B`@("!M>2`D
M<&%R(#T@<VAI9G0H0$%21U8I.PH@("`@;7D@)'II<#L*"@H@("`@:68@*&1E
M9FEN960@)'!A<BD@>PH@("`@("`@(&]P96X@;7D@)&9H+"`G/"<L("1P87(@
M;W(@9&EE(")#86YN;W0@9FEN9"`G)'!A<B<Z("0A(CL*("`@("`@("!B:6YM
M;V1E*"1F:"D["B`@("`@("`@8FQE<W,H)&9H+"`G24\Z.D9I;&4G*3L*"B`@
M("`@("`@)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PH@("`@("`@("@@)'II
M<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!A<BD@/3T@07)C:&EV93HZ
M6FEP.CI!6E]/2R@I("D*("`@("`@("`@("`@;W(@9&EE(")296%D("<D<&%R
M)R!E<G)O<CH@)"$B.PH@("`@?0H*"B`@("!M>2`E96YV(#T@9&\@>PH@("`@
M("`@(&EF("@D>FEP(&%N9"!M>2`D;65T82`]("1Z:7`M/F-O;G1E;G1S*"=-
M151!+GEM;"<I*2!["B`@("`@("`@("`@("1M971A(#U^(',O+BI><&%R.B0O
M+VUS.PH@("`@("`@("`@("`D;65T82`]?B!S+UY<4RXJ+R]M<SL*("`@("`@
M("`@("`@)&UE=&$@/7X@+UX@("A;7CI=*RDZ("@N*RDD+VUG.PH@("`@("`@
M('T*("`@('T["@H@("`@(R!/<&5N(&EN<'5T(&%N9"!O=71P=70@9FEL97,@
M>WM["B`@("!L;V-A;"`D+R`](%PT.PH*("`@(&EF("AD969I;F5D("1P87(I
M('L*("`@("`@("!O<&5N(%!!4BP@)SPG+"`D<&%R(&]R(&1I92`B)"$Z("1P
M87(B.PH@("`@("`@(&)I;FUO9&4H4$%2*3L*("`@("`@("!D:64@(B1P87(@
M:7,@;F]T(&$@4$%2(&9I;&4B('5N;&5S<R`\4$%2/B!E<2`B4$M<,#`S7#`P
M-"(["B`@("!]"@H@("`@0W)E871E4&%T:"@D;W5T*2`["B`@("`*("`@(&UY
M("1F:"`]($E/.CI&:6QE+3YN97<H"B`@("`@("`@)&]U="P*("`@("`@("!)
M3SHZ1FEL93HZ3U]#4D5!5"@I('P@24\Z.D9I;&4Z.D]?5U)/3DQ9*"D@?"!)
M3SHZ1FEL93HZ3U]44E5.0R@I+`H@("`@("`@(#`W-S<L"B`@("`I(&]R(&1I
M92`D(3L*("`@(&)I;FUO9&4H)&9H*3L*"B`@("`D+R`]("AD969I;F5D("1D
M871A7W!O<RD@/R!<)&1A=&%?<&]S(#H@=6YD968["B`@("!S965K(%]&2"P@
M,"P@,#L*("`@(&UY("1L;V%D97(@/2!S8V%L87(@/%]&2#X["B`@("!I9B`H
M(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@)&QO861E<B`]?B`O7B@_.B,A?%Q`
M<F5M*2\I('L*("`@("`@("!R97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I
M<#L*("`@("`@("!005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/FYE=RT^87!P;'DH
M7"1L;V%D97(L("0P*0H@("`@?0H@("`@9F]R96%C:"!M>2`D:V5Y("AS;W)T
M(&ME>7,@)65N=BD@>PH@("`@("`@(&UY("1V86P@/2`D96YV>R1K97E](&]R
M(&YE>'0["B`@("`@("`@)'9A;"`](&5V86P@)'9A;"!I9B`D=F%L(#U^("]>
M6R<B72\["B`@("`@("`@;7D@)&UA9VEC(#T@(E]?14Y67U!!4E\B("X@=6,H
M)&ME>2D@+B`B7U\B.PH@("`@("`@(&UY("1S970@/2`B4$%27R(@+B!U8R@D
M:V5Y*2`N("(])'9A;"(["B`@("`@("`@)&QO861E<B`]?B!S>R1M86=I8R@@
M*RE]>PH@("`@("`@("`@("`D;6%G:6,@+B`D<V5T("X@*"<@)R!X("AL96YG
M=&@H)#$I("T@;&5N9W1H*"1S970I*2D*("`@("`@("!]96<["B`@("!]"B`@
M("`D9F@M/G!R:6YT*"1L;V%D97(I.PH@("`@)"\@/2!U;F1E9CL*("`@(",@
M?7U]"@H@("`@(R!7<FET92!B=6YD;&5D(&UO9'5L97,@>WM["B`@("!I9B`H
M)&)U;F1L92D@>PH@("`@("`@(')E<75I<F4@4$%2.CI(96%V>3L*("`@("`@
M("!005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["B`@("`@("`@:6YI
M=%]I;F,H*3L*"B`@("`@("`@<F5Q=6ER95]M;V1U;&5S*"D["@H@("`@("`@
M(&UY($!I;F,@/2!S;W)T('L*("`@("`@("`@("`@;&5N9W1H*"1B*2`\/3X@
M;&5N9W1H*"1A*0H@("`@("`@('T@9W)E<"!["B`@("`@("`@("`@("$O0E-$
M4$%.+PH@("`@("`@('T@9W)E<"!["B`@("`@("`@("`@("@D8G5N9&QE(&YE
M("=S:71E)RD@;W(*("`@("`@("`@("`@*"1?(&YE("1#;VYF:6<Z.D-O;F9I
M9WMA<F-H;&EB97AP?2!A;F0*("`@("`@("`@("`@("1?(&YE("1#;VYF:6<Z
M.D-O;F9I9WMP<FEV;&EB97AP?2D["B`@("`@("`@?2!`24Y#.PH*("`@("`@
M("`C($9I;&4@97AI<W1S('1E<W0@861D960@=&\@9FEX(%)4(",T,3<Y,#H*
M("`@("`@("`C($9U;FYY+"!N;VXM97AI<W1I;F<@96YT<GD@:6X@7SPN+BXN
M875T;R]#;VUP<F5S<R]287<O6FQI8B]A=71O<W!L:70N:7@N"B`@("`@("`@
M(R!4:&ES(&ES(&$@8F%N9"UA:60@9FEX('=I=&@@;F\@9&5E<&5R(&=R87-P
M(&]F('1H92!I<W-U92X*("`@("`@("`C(%-O;65B;V1Y('!L96%S92!G;R!T
M:')O=6=H('1H92!P86EN(&]F('5N9&5R<W1A;F1I;F<@=VAA="=S(&AA<'!E
M;FEN9RP*("`@("`@("`C($D@9F%I;&5D+B`M+2!3=&5F9F5N"B`@("`@("`@
M;7D@)69I;&5S.PH@("`@("`@("]>7SPH+BLI)"\@86YD("UE("0Q(&%N9"`D
M9FEL97-[)#%]*RL@9F]R(&ME>7,@)3HZ.PH@("`@("`@("1F:6QE<WLD7WTK
M*R!F;W(@=F%L=65S("5)3D,["@H@("`@("`@(&UY("1L:6)?97AT(#T@)$-O
M;F9I9SHZ0V]N9FEG>VQI8E]E>'1].PH@("`@("`@(&UY("5W<FET=&5N.PH*
M("`@("`@("!F;W)E86-H("AS;W)T(&ME>7,@)69I;&5S*2!["B`@("`@("`@
M("`@(&UY("@D;F%M92P@)&9I;&4I.PH*("`@("`@("`@("`@9F]R96%C:"!M
M>2`D9&ER("A`:6YC*2!["B`@("`@("`@("`@("`@("!I9B`H)&YA;64@/2`D
M4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1??2D@>PH@("`@("`@("`@("`@("`@
M("`@("1F:6QE(#T@)%\["B`@("`@("`@("`@("`@("`@("`@;&%S=#L*("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@(&5L<VEF("@O7BA<421D
M:7)<15PO*"XJ6UY#8UTI*5Q:+VDI('L*("`@("`@("`@("`@("`@("`@("`H
M)&9I;&4L("1N86UE*2`]("@D,2P@)#(I.PH@("`@("`@("`@("`@("`@("`@
M(&QA<W0["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!E;'-I
M9B`H;2%>+VQO861E<B];7B]=*R\H+BI;7D-C72E<6B$I('L*("`@("`@("`@
M("`@("`@("`@("!I9B`H;7D@)')E9B`]("1005(Z.DAE879Y.CI-;V1U;&5#
M86-H97LD,7TI('L*("`@("`@("`@("`@("`@("`@("`@("`@*"1F:6QE+"`D
M;F%M92D@/2`H)')E9BP@)#$I.PH@("`@("`@("`@("`@("`@("`@("`@("!L
M87-T.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@
M("!E;'-I9B`H+68@(B1D:7(O)#$B*2!["B`@("`@("`@("`@("`@("`@("`@
M("`@("@D9FEL92P@)&YA;64I(#T@*"(D9&ER+R0Q(BP@)#$I.PH@("`@("`@
M("`@("`@("`@("`@("`@("!L87-T.PH@("`@("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H*("`@("`@("`@("`@
M;F5X="!U;FQE<W,@9&5F:6YE9"`D;F%M92!A;F0@;F]T("1W<FET=&5N>R1N
M86UE?2LK.PH@("`@("`@("`@("!N97AT(&EF("%R968H)&9I;&4I(&%N9"`D
M9FEL92`]?B`O7"Y<421L:6)?97AT7$4D+SL*("`@("`@("`@("`@;W5T<R@@
M:F]I;B`B(BP*("`@("`@("`@("`@("`@('%Q*%!A8VMI;F<@(BDL(')E9B`D
M9FEL92`_("1F:6QE+3Y[;F%M97T@.B`D9FEL92P*("`@("`@("`@("`@("`@
M('%Q*"(N+BXI"B`@("`@("`@("`@("D["@H@("`@("`@("`@("!M>2`D8V]N
M=&5N=#L*("`@("`@("`@("`@:68@*')E9B@D9FEL92DI('L*("`@("`@("`@
M("`@("`@("1C;VYT96YT(#T@)&9I;&4M/GMB=69].PH@("`@("`@("`@("!]
M"B`@("`@("`@("`@(&5L<V4@>PH@("`@("`@("`@("`@("`@;W!E;B!&24Q%
M+"`G/"<L("1F:6QE(&]R(&1I92`B0V%N)W0@;W!E;B`D9FEL93H@)"$B.PH@
M("`@("`@("`@("`@("`@8FEN;6]D92A&24Q%*3L*("`@("`@("`@("`@("`@
M("1C;VYT96YT(#T@/$9)3$4^.PH@("`@("`@("`@("`@("`@8VQO<V4@1DE,
M13L*"B`@("`@("`@("`@("`@("!005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/FYE
M=RT^87!P;'DH7"1C;VYT96YT+"`D9FEL92D*("`@("`@("`@("`@("`@("`@
M("!I9B`A)$5.5GM005)?5D520D%424U](&%N9"`D;F%M92`]?B`O7"XH/SIP
M;7QI>'QA;"DD+VD["@H@("`@("`@("`@("`@("`@4$%2.CI&:6QT97(Z.E!A
M=&-H0V]N=&5N="T^;F5W+3YA<'!L>2A<)&-O;G1E;G0L("1F:6QE+"`D;F%M
M92D["B`@("`@("`@("`@('T*"B`@("`@("`@("`@(&]U=',H<7$H5W)I='1E
M;B!A<R`B)&YA;64B*2D["B`@("`@("`@("`@("1F:"T^<')I;G0H(D9)3$4B
M*3L*("`@("`@("`@("`@)&9H+3YP<FEN="AP86-K*"=.)RP@;&5N9W1H*"1N
M86UE*2`K(#DI*3L*("`@("`@("`@("`@)&9H+3YP<FEN="AS<')I;G1F*`H@
M("`@("`@("`@("`@("`@(B4P.'@O)7,B+"!!<F-H:79E.CI::7`Z.F-O;7!U
M=&5#4D,S,B@D8V]N=&5N="DL("1N86UE"B`@("`@("`@("`@("DI.PH@("`@
M("`@("`@("`D9F@M/G!R:6YT*'!A8VLH)TXG+"!L96YG=&@H)&-O;G1E;G0I
M*2D["B`@("`@("`@("`@("1F:"T^<')I;G0H)&-O;G1E;G0I.PH@("`@("`@
M('T*("`@('T*("`@(",@?7U]"@H@("`@(R!.;W<@=W)I=&4@;W5T('1H92!0
M05(@86YD(&UA9VEC('-T<FEN9W,@>WM["B`@("`D>FEP+3YW<FET951O1FEL
M94AA;F1L92@D9F@I(&EF("1Z:7`["@H@("`@)&-A8VAE7VYA;64@/2!S=6)S
M='(@)&-A8VAE7VYA;64L(#`L(#0P.PH@("`@:68@*"$D8V%C:&5?;F%M92!A
M;F0@;7D@)&UT:6UE(#T@*'-T870H)&]U="DI6SE=*2!["B`@("`@("`@;7D@
M)&-T>"`](&5V86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!.R!$:6=E<W0Z.E-(
M02T^;F5W*#$I('T*("`@("`@("`@("`@?'P@979A;"![(')E<75I<F4@1&EG
M97-T.CI32$$Q.R!$:6=E<W0Z.E-(03$M/FYE=R!]"B`@("`@("`@("`@('Q\
M(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ340U.R!$:6=E<W0Z.DU$-2T^;F5W
M('T["@H@("`@("`@(",@5V]R:V%R;W5N9"!F;W(@8G5G(&EN($1I9V5S=#HZ
M4TA!(#4N,S@@86YD(#4N,SD*("`@("`@("!M>2`D<VAA7W9E<G-I;VX@/2!E
M=F%L('L@)$1I9V5S=#HZ4TA!.CI615)324].('T@?'P@,#L*("`@("`@("!I
M9B`H)'-H85]V97)S:6]N(&5Q("<U+C,X)R!O<B`D<VAA7W9E<G-I;VX@97$@
M)S4N,SDG*2!["B`@("`@("`@("`@("1C='@M/F%D9&9I;&4H)&]U="P@(F(B
M*2!I9B`H)&-T>"D["B`@("`@("`@?0H@("`@("`@(&5L<V4@>PH@("`@("`@
M("`@("!I9B`H)&-T>"!A;F0@;W!E;BAM>2`D9F@L("(\)&]U="(I*2!["B`@
M("`@("`@("`@("`@("!B:6YM;V1E*"1F:"D["B`@("`@("`@("`@("`@("`D
M8W1X+3YA9&1F:6QE*"1F:"D["B`@("`@("`@("`@("`@("!C;&]S92@D9F@I
M.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`D8V%C:&5?;F%M
M92`]("1C='@@/R`D8W1X+3YH97AD:6=E<W0@.B`D;71I;64["B`@("!]"B`@
M("`D8V%C:&5?;F%M92`N/2`B7#`B('@@*#0Q("T@;&5N9W1H("1C86-H95]N
M86UE*3L*("`@("1C86-H95]N86UE("X](")#04-(12(["B`@("`D9F@M/G!R
M:6YT*"1C86-H95]N86UE*3L*("`@("1F:"T^<')I;G0H<&%C:R@G3B<L("1F
M:"T^=&5L;"`M(&QE;F=T:"@D;&]A9&5R*2DI.PH@("`@)&9H+3YP<FEN="@B
M7&Y005(N<&U<;B(I.PH@("`@)&9H+3YC;&]S93L*("`@(&-H;6]D(#`W-34L
M("1O=70["B`@("`C('U]?0H*("`@(&5X:70["GT*(R!]?7T*"B,@4')E<&%R
M92`D<')O9VYA;64@:6YT;R!005(@9FEL92!C86-H92![>WL*>PH@("`@;&%S
M="!U;FQE<W,@9&5F:6YE9"`D<W1A<G1?<&]S.PH*("`@(%]F:7A?<')O9VYA
M;64H*3L*"B`@("`C($YO=R!L;V%D('1H92!005(@9FEL92!A;F0@<'5T(&ET
M(&EN=&\@4$%2.CI,:6)#86-H92![>WL*("`@(')E<75I<F4@4$%2.PH@("`@
M4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PH*"B`@("!["B`@("`@
M("`@(VQO8V%L("1)3D-[)T-W9"YP;2=](#T@7U]&24Q%7U\@:68@)%Y/(&YE
M("=-4U=I;C,R)SL*("`@("`@("!R97%U:7)E($9I;&4Z.D9I;F0["B`@("`@
M("`@<F5Q=6ER92!!<F-H:79E.CI::7`["B`@("!]"B`@("!M>2`D>FEP(#T@
M07)C:&EV93HZ6FEP+3YN97<["B`@("!M>2`D9F@@/2!)3SHZ1FEL92T^;F5W
M.PH@("`@)&9H+3YF9&]P96XH9FEL96YO*%]&2"DL("=R)RD@;W(@9&EE("(D
M(3H@)$`B.PH@("`@)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!R
M;V=N86UE*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"D@;W(@9&EE("(D(3H@
M)$`B.PH*("`@('!U<V@@0%!!4CHZ3&EB0V%C:&4L("1Z:7`["B`@("`D4$%2
M.CI,:6)#86-H97LD<')O9VYA;65](#T@)'II<#L*"B`@("`D<75I970@/2`A
M)$5.5GM005)?1$5"54=].PH@("`@;W5T<RAQ<2A<)$5.5GM005)?5$5-4'T@
M/2`B)$5.5GM005)?5$5-4'TB*2D["@H@("`@:68@*&1E9FEN960@)$5.5GM0
M05)?5$5-4'TI('L@(R!S:&]U;&0@8F4@<V5T(&%T('1H:7,@<&]I;G0A"B`@
M("`@("`@9F]R96%C:"!M>2`D;65M8F5R("@@)'II<"T^;65M8F5R<R`I('L*
M("`@("`@("`@("`@;F5X="!I9B`D;65M8F5R+3YI<T1I<F5C=&]R>3L*("`@
M("`@("`@("`@;7D@)&UE;6)E<E]N86UE(#T@)&UE;6)E<BT^9FEL94YA;64[
M"B`@("`@("`@("`@(&YE>'0@=6YL97-S("1M96UB97)?;F%M92`]?B!M>PH@
M("`@("`@("`@("`@("`@7@H@("`@("`@("`@("`@("`@+S]S:&QI8B\*("`@
M("`@("`@("`@("`@("@_.B1#;VYF:6<Z.D-O;F9I9WMV97)S:6]N?2\I/PH@
M("`@("`@("`@("`@("`@*#\Z)$-O;F9I9SHZ0V]N9FEG>V%R8VAN86UE?2\I
M/PH@("`@("`@("`@("`@("`@*%M>+UTK*0H@("`@("`@("`@("`@("`@)`H@
M("`@("`@("`@("!]>#L*("`@("`@("`@("`@;7D@)&5X=')A8W1?;F%M92`]
M("0Q.PH@("`@("`@("`@("!M>2`D9&5S=%]N86UE(#T@1FEL93HZ4W!E8RT^
M8V%T9FEL92@D14Y6>U!!4E]414U0?2P@)&5X=')A8W1?;F%M92D["B`@("`@
M("`@("`@(&EF("@M9B`D9&5S=%]N86UE("8F("US(%\@/3T@)&UE;6)E<BT^
M=6YC;VUP<F5S<V5D4VEZ92@I*2!["B`@("`@("`@("`@("`@("!O=71S*'%Q
M*%-K:7!P:6YG("(D;65M8F5R7VYA;64B('-I;F-E(&ET(&%L<F5A9'D@97AI
M<W1S(&%T("(D9&5S=%]N86UE(BDI.PH@("`@("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`@("`@;W5T<RAQ<2A%>'1R86-T:6YG("(D;65M8F5R7VYA
M;64B('1O("(D9&5S=%]N86UE(BDI.PH@("`@("`@("`@("`@("`@)&UE;6)E
M<BT^97AT<F%C=%1O1FEL94YA;65D*"1D97-T7VYA;64I.PH@("`@("`@("`@
M("`@("`@8VAM;V0H,#4U-2P@)&1E<W1?;F%M92D@:68@)%Y/(&5Q(")H<'5X
M(CL*("`@("`@("`@("`@?0H@("`@("`@('T*("`@('T*("`@(",@?7U]"GT*
M(R!]?7T*"B,@268@=&AE<F4G<R!N;R!M86EN+G!L('1O(')U;BP@<VAO=R!U
M<V%G92![>WL*=6YL97-S("@D4$%2.CI,:6)#86-H97LD<')O9VYA;65]*2![
M"B`@("!D:64@/#P@(BXB('5N;&5S<R!`05)'5CL*57-A9V4Z("0P(%L@+4%L
M:6(N<&%R(%T@6R`M261I<B!=(%L@+4UM;V1U;&4@72!;('-R8RYP87(@72!;
M('!R;V=R86TN<&P@70H@("`@("`@)#`@6R`M0GPM8B!=(%LM3V]U=&9I;&5=
M('-R8RYP87(*+@H@("`@)$5.5GM005)?4%)/1TY!345](#T@)'!R;V=N86UE
M(#T@)#`@/2!S:&EF="A`05)'5BD["GT*(R!]?7T*"G-U8B!#<F5A=&50871H
M('L*("`@(&UY("@D;F%M92D@/2!`7SL*("`@(`H@("`@<F5Q=6ER92!&:6QE
M.CI"87-E;F%M93L*("`@(&UY("@D8F%S96YA;64L("1P871H+"`D97AT*2`]
M($9I;&4Z.D)A<V5N86UE.CIF:6QE<&%R<V4H)&YA;64L("@G7"XN*B<I*3L*
M("`@(`H@("`@<F5Q=6ER92!&:6QE.CI0871H.PH@("`@"B`@("!&:6QE.CI0
M871H.CIM:W!A=&@H)'!A=&@I('5N;&5S<R@M92`D<&%T:"D[(",@;6MP871H
M(&1I97,@=VET:"!E<G)O<@I]"@IS=6(@<F5Q=6ER95]M;V1U;&5S('L*("`@
M("-L;V-A;"`D24Y#>R=#=V0N<&TG?2`](%]?1DE,15]?(&EF("1>3R!N92`G
M35-7:6XS,B<["@H@("`@<F5Q=6ER92!L:6(["B`@("!R97%U:7)E($1Y;F%,
M;V%D97(["B`@("!R97%U:7)E(&EN=&5G97(["B`@("!R97%U:7)E('-T<FEC
M=#L*("`@(')E<75I<F4@=V%R;FEN9W,["B`@("!R97%U:7)E('9A<G,["B`@
M("!R97%U:7)E($-A<G`["B`@("!R97%U:7)E($-A<G`Z.DAE879Y.PH@("`@
M<F5Q=6ER92!%<G)N;SL*("`@(')E<75I<F4@17AP;W)T97(Z.DAE879Y.PH@
M("`@<F5Q=6ER92!%>'!O<G1E<CL*("`@(')E<75I<F4@1F-N=&P["B`@("!R
M97%U:7)E($9I;&4Z.E1E;7`["B`@("!R97%U:7)E($9I;&4Z.E-P96,["B`@
M("!R97%U:7)E(%A33&]A9&5R.PH@("`@<F5Q=6ER92!#;VYF:6<["B`@("!R
M97%U:7)E($E/.CI(86YD;&4["B`@("!R97%U:7)E($E/.CI&:6QE.PH@("`@
M<F5Q=6ER92!#;VUP<F5S<SHZ6FQI8CL*("`@(')E<75I<F4@07)C:&EV93HZ
M6FEP.PH@("`@<F5Q=6ER92!005(["B`@("!R97%U:7)E(%!!4CHZ2&5A=GD[
M"B`@("!R97%U:7)E(%!!4CHZ1&ES=#L*("`@(')E<75I<F4@4$%2.CI&:6QT
M97(Z.E!O9%-T<FEP.PH@("`@<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&%T8VA#
M;VYT96YT.PH@("`@<F5Q=6ER92!A='1R:6)U=&5S.PH@("`@979A;"![(')E
M<75I<F4@0W=D('T["B`@("!E=F%L('L@<F5Q=6ER92!7:6XS,B!].PH@("`@
M979A;"![(')E<75I<F4@4V-A;&%R.CI5=&EL('T["B`@("!E=F%L('L@<F5Q
M=6ER92!!<F-H:79E.CI5;GII<#HZ0G5R<W0@?3L*("`@(&5V86P@>R!R97%U
M:7)E(%1I93HZ2&%S:#HZ3F%M961#87!T=7)E('T["B`@("!E=F%L('L@<F5Q
M=6ER92!097)L24\[(')E<75I<F4@4&5R;$E/.CIS8V%L87(@?3L*?0H*(R!4
M:&4@0R!V97)S:6]N(&]F('1H:7,@8V]D92!A<'!E87)S(&EN(&UY;&1R+VUK
M=&UP9&ER+F,*(R!4:&ES(&-O9&4@86QS;R!L:79E<R!I;B!005(Z.E-E='5P
M5&5M<"!A<R!S971?<&%R7W1E;7!?96YV(0IS=6(@7W-E=%]P87)?=&5M<"![
M"B`@("!I9B`H9&5F:6YE9"`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?
M5$5-4'T@/7X@+R@N*RDO*2!["B`@("`@("`@)'!A<E]T96UP(#T@)#$["B`@
M("`@("`@<F5T=7)N.PH@("`@?0H*("`@(&9O<F5A8V@@;7D@)'!A=&@@*`H@
M("`@("`@("AM87`@)$5.5GLD7WTL('%W*"!005)?5$U01$E2(%1-4$1)4B!4
M14U01$E2(%1%35`@5$U0("DI+`H@("`@("`@('%W*"!#.EQ<5$5-4"`O=&UP
M("X@*0H@("`@*2!["B`@("`@("`@;F5X="!U;FQE<W,@9&5F:6YE9"`D<&%T
M:"!A;F0@+60@)'!A=&@@86YD("UW("1P871H.PH@("`@("`@(&UY("1U<V5R
M;F%M93L*("`@("`@("!M>2`D<'=U:60["B`@("`@("`@(R!D;V5S(&YO="!W
M;W)K(&5V97)Y=VAE<F4Z"B`@("`@("`@979A;"![*"1P=W5I9"D@/2!G971P
M=W5I9"@D/BD@:68@9&5F:6YE9"`D/CM].PH*("`@("`@("!I9B`H(&1E9FEN
M960H)E=I;C,R.CI,;V=I;DYA;64I("D@>PH@("`@("`@("`@("`D=7-E<FYA
M;64@/2`F5VEN,S(Z.DQO9VEN3F%M93L*("`@("`@("!]"B`@("`@("`@96QS
M:68@*&1E9FEN960@)'!W=6ED*2!["B`@("`@("`@("`@("1U<V5R;F%M92`]
M("1P=W5I9#L*("`@("`@("!]"B`@("`@("`@96QS92!["B`@("`@("`@("`@
M("1U<V5R;F%M92`]("1%3E9[55-%4DY!345]('Q\("1%3E9[55-%4GT@?'P@
M)U-94U1%32<["B`@("`@("`@?0H@("`@("`@("1U<V5R;F%M92`]?B!S+UQ7
M+U\O9SL*"B`@("`@("`@;7D@)'-T;7!D:7(@/2`B)'!A=&@D0V]N9FEG>U]D
M96QI;7UP87(M)'5S97)N86UE(CL*("`@("`@("!M:V1I<B`D<W1M<&1I<BP@
M,#<U-3L*("`@("`@("!I9B`H(21%3E9[4$%27T-,14%.?2!A;F0@;7D@)&UT
M:6UE(#T@*'-T870H)'!R;V=N86UE*2E;.5TI('L*("`@("`@("`@("`@;W!E
M;B`H;7D@)&9H+"`B/"(N("1P<F]G;F%M92D["B`@("`@("`@("`@('-E96L@
M)&9H+"`M,3@L(#(["B`@("`@("`@("`@('-Y<W)E860@)&9H+"!M>2`D8G5F
M+"`V.PH@("`@("`@("`@("!I9B`H)&)U9B!E<2`B7#!#04-(12(I('L*("`@
M("`@("`@("`@("`@('-E96L@)&9H+"`M-3@L(#(["B`@("`@("`@("`@("`@
M("!S>7-R96%D("1F:"P@)&)U9BP@-#$["B`@("`@("`@("`@("`@("`D8G5F
M(#U^(',O7#`O+V<["B`@("`@("`@("`@("`@("`D<W1M<&1I<B`N/2`B)$-O
M;F9I9WM?9&5L:6U]8V%C:&4M(B`N("1B=68["B`@("`@("`@("`@('T*("`@
M("`@("`@("`@96QS92!["B`@("`@("`@("`@("`@("!M>2`D8W1X(#T@979A
M;"![(')E<75I<F4@1&EG97-T.CI32$$[($1I9V5S=#HZ4TA!+3YN97<H,2D@
M?0H@("`@("`@("`@("`@("`@("`@('Q\(&5V86P@>R!R97%U:7)E($1I9V5S
M=#HZ4TA!,3L@1&EG97-T.CI32$$Q+3YN97<@?0H@("`@("`@("`@("`@("`@
M("`@('Q\(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ340U.R!$:6=E<W0Z.DU$
M-2T^;F5W('T["@H@("`@("`@("`@("`@("`@(R!7;W)K87)O=6YD(&9O<B!B
M=6<@:6X@1&EG97-T.CI32$$@-2XS."!A;F0@-2XS.0H@("`@("`@("`@("`@
M("`@;7D@)'-H85]V97)S:6]N(#T@979A;"![("1$:6=E<W0Z.E-(03HZ5D52
M4TE/3B!]('Q\(#`["B`@("`@("`@("`@("`@("!I9B`H)'-H85]V97)S:6]N
M(&5Q("<U+C,X)R!O<B`D<VAA7W9E<G-I;VX@97$@)S4N,SDG*2!["B`@("`@
M("`@("`@("`@("`@("`@)&-T>"T^861D9FEL92@D<')O9VYA;64L(")B(BD@
M:68@*"1C='@I.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@
M96QS92!["B`@("`@("`@("`@("`@("`@("`@:68@*"1C='@@86YD(&]P96XH
M;7D@)&9H+"`B/"1P<F]G;F%M92(I*2!["B`@("`@("`@("`@("`@("`@("`@
M("`@(&)I;FUO9&4H)&9H*3L*("`@("`@("`@("`@("`@("`@("`@("`@)&-T
M>"T^861D9FEL92@D9F@I.PH@("`@("`@("`@("`@("`@("`@("`@("!C;&]S
M92@D9F@I.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@
M('T*"B`@("`@("`@("`@("`@("`D<W1M<&1I<B`N/2`B)$-O;F9I9WM?9&5L
M:6U]8V%C:&4M(B`N("@@)&-T>"`_("1C='@M/FAE>&1I9V5S="`Z("1M=&EM
M92`I.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&-L;W-E*"1F:"D["B`@
M("`@("`@?0H@("`@("`@(&5L<V4@>PH@("`@("`@("`@("`D14Y6>U!!4E]#
M3$5!3GT@/2`Q.PH@("`@("`@("`@("`D<W1M<&1I<B`N/2`B)$-O;F9I9WM?
M9&5L:6U]=&5M<"TD)"(["B`@("`@("`@?0H*("`@("`@("`D14Y6>U!!4E]4
M14U0?2`]("1S=&UP9&ER.PH@("`@("`@(&UK9&ER("1S=&UP9&ER+"`P-S4U
M.PH@("`@("`@(&QA<W0["B`@("!]"@H@("`@)'!A<E]T96UP(#T@)#$@:68@
M)$5.5GM005)?5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI+SL*
M?0H*<W5B(%]T96UP9FEL92!["B`@("!M>2`H)&5X="P@)&-R8RD@/2!`7SL*
M("`@(&UY("@D9F@L("1F:6QE;F%M92D["@H@("`@)&9I;&5N86UE(#T@(B1P
M87)?=&5M<"\D8W)C)&5X="(["@H@("`@:68@*"1%3E9[4$%27T-,14%.?2D@
M>PH@("`@("`@('5N;&EN:R`D9FEL96YA;64@:68@+64@)&9I;&5N86UE.PH@
M("`@("`@('!U<V@@0'1M<&9I;&4L("1F:6QE;F%M93L*("`@('T*("`@(&5L
M<V4@>PH@("`@("`@(')E='5R;B`H=6YD968L("1F:6QE;F%M92D@:68@*"UR
M("1F:6QE;F%M92D["B`@("!]"@H@("`@;W!E;B`D9F@L("<^)RP@)&9I;&5N
M86UE(&]R(&1I92`D(3L*("`@(&)I;FUO9&4H)&9H*3L*("`@(')E='5R;B@D
M9F@L("1F:6QE;F%M92D["GT*"B,@<V%M92!C;V1E(&QI=F5S(&EN(%!!4CHZ
M4V5T=7!0<F]G;F%M93HZ<V5T7W!R;V=N86UE"G-U8B!?<V5T7W!R;V=N86UE
M('L*("`@(&EF("AD969I;F5D("1%3E9[4$%27U!23T=.04U%?2!A;F0@)$5.
M5GM005)?4%)/1TY!345](#U^("\H+BLI+RD@>PH@("`@("`@("1P<F]G;F%M
M92`]("0Q.PH@("`@?0H*("`@("1P<F]G;F%M92!\?#T@)#`["@H@("`@:68@
M*"1%3E9[4$%27U1%35!](&%N9"!I;F1E>"@D<')O9VYA;64L("1%3E9[4$%2
M7U1%35!]*2`^/2`P*2!["B`@("`@("`@)'!R;V=N86UE(#T@<W5B<W1R*"1P
M<F]G;F%M92P@<FEN9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`K
M(#$I.PH@("`@?0H*("`@(&EF("@A)$5.5GM005)?4%)/1TY!345](&]R(&EN
M9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`^/2`P*2!["B`@("`@
M("`@:68@*&]P96X@;7D@)&9H+"`G/"<L("1P<F]G;F%M92D@>PH@("`@("`@
M("`@("!R971U<FX@:68@+7,@)&9H.PH@("`@("`@('T*("`@("`@("!I9B`H
M+7,@(B1P<F]G;F%M921#;VYF:6=[7V5X97TB*2!["B`@("`@("`@("`@("1P
M<F]G;F%M92`N/2`D0V]N9FEG>U]E>&5].PH@("`@("`@("`@("!R971U<FX[
M"B`@("`@("`@?0H@("`@?0H*("`@(&9O<F5A8V@@;7D@)&1I<B`H<W!L:70@
M+UQ1)$-O;F9I9WMP871H7W-E<'U<12\L("1%3E9[4$%42'TI('L*("`@("`@
M("!N97AT(&EF(&5X:7-T<R`D14Y6>U!!4E]414U0?2!A;F0@)&1I<B!E<2`D
M14Y6>U!!4E]414U0?3L*("`@("`@("`D9&ER(#U^(',O7%$D0V]N9FEG>U]D
M96QI;7U<120O+SL*("`@("`@("`H*"1P<F]G;F%M92`]("(D9&ER)$-O;F9I
M9WM?9&5L:6U])'!R;V=N86UE)$-O;F9I9WM?97AE?2(I+"!L87-T*0H@("`@
M("`@("`@("!I9B`M<R`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M921#
M;VYF:6=[7V5X97TB.PH@("`@("`@("@H)'!R;V=N86UE(#T@(B1D:7(D0V]N
M9FEG>U]D96QI;7TD<')O9VYA;64B*2P@;&%S="D*("`@("`@("`@("`@:68@
M+7,@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64B.PH@("`@?0I]"@IS
M=6(@7V9I>%]P<F]G;F%M92!["B`@("`D,"`]("1P<F]G;F%M92!\?#T@)$5.
M5GM005)?4%)/1TY!345].PH@("`@:68@*&EN9&5X*"1P<F]G;F%M92P@)$-O
M;F9I9WM?9&5L:6U]*2`\(#`I('L*("`@("`@("`D<')O9VYA;64@/2`B+B1#
M;VYF:6=[7V1E;&EM?21P<F]G;F%M92(["B`@("!]"@H@("`@(R!86%@@+2!H
M86-K('1O(&UA:V4@4%=$('=O<FL*("`@(&UY("1P=V0@/2`H9&5F:6YE9"`F
M0W=D.CIG971C=V0I(#\@0W=D.CIG971C=V0H*0H@("`@("`@("`@("`@("`@
M.B`H*&1E9FEN960@)E=I;C,R.CI'971#=V0I(#\@5VEN,S(Z.D=E=$-W9"@I
M(#H@8'!W9&`I.PH@("`@8VAO;7`H)'!W9"D["B`@("`D<')O9VYA;64@/7X@
M<R]>*#\]7"Y<+C]<421#;VYF:6=[7V1E;&EM?5Q%*2\D<'=D)$-O;F9I9WM?
M9&5L:6U]+SL*"B`@("`D14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64[
M"GT*"G-U8B!?<&%R7VEN:71?96YV('L*("`@(&EF("@@)$5.5GM005)?24Y)
M5$E!3$E:141]*RL@/3T@,2`I('L*("`@("`@("!R971U<FX["B`@("!](&5L
M<V4@>PH@("`@("`@("1%3E9[4$%27TE.251)04Q)6D5$?2`](#(["B`@("!]
M"@H@("`@9F]R("AQ=R@@4U!!5TY%1"!414U0($-,14%.($1%0E5'($-!0TA%
M(%!23T=.04U%($%21T,@05)'5E\P("D@*2!["B`@("`@("`@9&5L971E("1%
M3E9[)U!!4E\G+B1??3L*("`@('T*("`@(&9O<B`H<7<O(%1-4$1)4B!414U0
M($-,14%.($1%0E5'("\I('L*("`@("`@("`D14Y6>R=005)?)RXD7WT@/2`D
M14Y6>R=005)?1TQ/0D%,7R<N)%]](&EF(&5X:7-T<R`D14Y6>R=005)?1TQ/
M0D%,7R<N)%]].PH@("`@?0H*("`@(&UY("1P87)?8VQE86X@/2`B7U]%3E9?
M4$%27T-,14%.7U\@("`@("`@("`@("`@("`B.PH*("`@(&EF("@D14Y6>U!!
M4E]414U0?2D@>PH@("`@("`@(&1E;&5T92`D14Y6>U!!4E]#3$5!3GT["B`@
M("!]"B`@("!E;'-I9B`H(65X:7-T<R`D14Y6>U!!4E]'3$]"04Q?0TQ%04Y]
M*2!["B`@("`@("`@;7D@)'9A;'5E(#T@<W5B<W1R*"1P87)?8VQE86XL(#$R
M("L@;&5N9W1H*")#3$5!3B(I*3L*("`@("`@("`D14Y6>U!!4E]#3$5!3GT@
M/2`D,2!I9B`D=F%L=64@/7X@+UY005)?0TQ%04X]*%Q3*RDO.PH@("`@?0I]
M"@IS=6(@;W5T<R!["B`@("!R971U<FX@:68@)'%U:65T.PH@("`@:68@*"1L
M;V=F:"D@>PH@("`@("`@('!R:6YT("1L;V=F:"`B0%]<;B(["B`@("!]"B`@
M("!E;'-E('L*("`@("`@("!P<FEN="`B0%]<;B(["B`@("!]"GT*"G-U8B!I
M;FET7VEN8R!["B`@("!R97%U:7)E($-O;F9I9SL*("`@('!U<V@@0$E.0RP@
M9W)E<"!D969I;F5D+"!M87`@)$-O;F9I9SHZ0V]N9FEG>R1??2P@<7<H"B`@
M("`@("`@87)C:&QI8F5X<"!P<FEV;&EB97AP('-I=&5A<F-H97AP('-I=&5L
M:6)E>'`*("`@("`@("!V96YD;W)A<F-H97AP('9E;F1O<FQI8F5X<`H@("`@
M*3L*?0H*(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C
M(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C"B,@5&AE(&UA:6X@
M<&%C:V%G92!F;W(@<V-R:7!T(&5X96-U=&EO;@H*<&%C:V%G92!M86EN.PH*
M<F5Q=6ER92!005(["G5N<VAI9G0@0$E.0RP@7"9005(Z.F9I;F1?<&%R.PI0
M05(M/FEM<&]R="A`<&%R7V%R9W,I.PH*9&EE('%Q*'!A<BYP;#H@0V%N)W0@
M;W!E;B!P97)L('-C<FEP="`B)'!R;V=N86UE(CH@3F\@<W5C:"!F:6QE(&]R
M(&1I<F5C=&]R>5QN*0H@("`@=6YL97-S("UE("1P<F]G;F%M93L*"F1O("1P
M<F]G;F%M93L*0T]213HZ97AI="@D,2D@:68@*"1`(#U^+UY?5$M?15A)5%]<
M*"A<9"LI7"DO*3L*9&EE("1`(&EF("1`.PH*?3L*"B0Z.E]?15)23U(@/2`D
M0"!I9B`D0#L*?0H*0T]213HZ97AI="@D,2D@:68@*"0Z.E]?15)23U(@/7XO
M7E]42U]%6$E47UPH*%QD*RE<*2\I.PID:64@)#HZ7U]%4E)/4B!I9B`D.CI?
M7T524D]2.PH*,3L*"B-L:6YE(#$P,3$*"E]?14Y$7U\*`$=#0SH@*$1E8FEA
M;B`T+C8N,BTT*2`T+C8N,@!'0T,Z("A$96)I86X@-"XT+C8M,3`I(#0N-"XV
M`$$````39VYU``$````+!`$(`0P"`"YS:'-T<G1A8@`N:6YT97)P`"YN;W1E
M+D%"22UT86<`+FYO=&4N9VYU+F)U:6QD+6ED`"YG;G4N:&%S:``N9'EN<WEM
M`"YD>6YS='(`+F=N=2YV97)S:6]N`"YG;G4N=F5R<VEO;E]R`"YR96QA+F1Y
M;@`N<F5L82YP;'0`+FEN:70`+G1E>'0`+F9I;FD`+G)O9&%T80`N96A?9G)A
M;65?:&1R`"YE:%]F<F%M90`N8W1O<G,`+F1T;W)S`"YJ8W(`+F=O=#(`+F1Y
M;F%M:6,`+F=O=``N9&%T80`N8G-S`"YC;VUM96YT`"YG;G4N871T<FEB=71E
M<P``````````````````````````````````````````````````````````
M````"P````$````"$``!-````30````-```````````````!`````````!,`
M```'`````A```40```%$````(```````````````!``````````A````!P``
M``(0``%D```!9````"0```````````````0`````````.`````4````"$``!
MB````8@```,L````!@`````````$````!````#1O___V`````A``!+0```2T
M````_`````8`````````!`````0````^````"P````(0``6P```%L```!H``
M```'`````0````0````0````1@````,````"$``,,```##````3X````````
M```````!`````````$YO____`````A``$2@``!$H````T`````8`````````
M`@````(```!;;____@````(0`!'X```1^````)`````'`````@````0`````
M````:@````0````"$``2B```$H@```#,````!@`````````$````#````'0`
M```$`````A``$U0``!-4```#,`````8````8````!`````P```!^`````0``
M``80`!:$```6A````$P```````````````0`````````A`````$````&$``6
MT```%M```$@````````````````0`````````(H````!````!A``7M```%[0
M````.```````````````!`````````"0`````0````(0`%\(``!?"```!#``
M``````````````@`````````F`````$````"$`!C.```8S@````4````````
M```````$`````````*8````!`````A``8TP``&-,````5```````````````
M!`````````"P`````0````,0`7````!P``````@```````````````0`````
M````MP````$````#$`%P"```<`@````(```````````````$`````````+X`
M```!`````Q`!<!```'`0````!```````````````!`````````##`````0``
M``,0`7`4``!P%`````P```````````````$`````````R0````8````#$`%P
M(```<"````$(````!P`````````$````"````-(````!`````Q`!<2@``'$H
M````$```````````````!`````0```!Y`````0````,0`7$X``!Q.````1``
M``````````````0`````````UP````$````#$`%R2```<D@``%NQ````````
M```````$`````````-T````(`````Q`!S?P``,WY```0/```````````````
M!`````````#B`````0```#````````#-^0```#D```````````````$````!
M````ZV____4`````````````SC(````4```````````````!``````````$`
C```#`````````````,Y&````^P```````````````0``````
